import React, { useState } from "react";

import { Field, Form } from "react-final-form";
import { Link } from "react-router-dom";

import { PrimaryButton, SecondaryButton } from "../../ui/atoms/Button";
import {
  SearchColField,
  SearchField,
  SearchLabel,
  SearchRow,
} from "../../ui/atoms/EventsLog";
import { FilterSort, FilterSortItem } from "../../ui/atoms/FilterSort";
import { TextInput } from "../../ui/atoms/Input";
import { Table, Tbody, Td, Th, Thead, Tr } from "../../ui/atoms/Table";
import Dropdown from "../../ui/molecules/Dropdown";
import Pagebar from "../../ui/molecules/Pagebar";
import Pagination from "../../ui/molecules/Pagination";
import Sortable from "../../ui/molecules/Sortable";
import SortableTh from "../../ui/molecules/SortableTh";
import { ActionTakenOptions } from "./constants";

export type ListProps = {};

const List: React.FC<ListProps> = () => {
  const [filter, setFilter] = useState([]);

  const handleFilterSubmit = (values) => {
    if (!values || !Object.keys(values).length) {
      return setFilter([]);
    }

    return filter; /**TODO query for search */
  };

  const handleFilterReset = (cb: () => void) => {
    cb();
    setFilter([]);
  };

  return (
    <>
      <h2>View Property Event Log</h2>

      <Form
        onSubmit={handleFilterSubmit}
        render={({ handleSubmit, form, submitting, pristine }) => (
          <form action="#" onSubmit={handleSubmit}>
            <SearchRow>
              <SearchColField>
                <SearchLabel htmlFor="search_property">Property:</SearchLabel>
                <SearchField>
                  <Field
                    component={TextInput}
                    name="search_property"
                    placeholder="Enter Property details/ID"
                  />
                </SearchField>
              </SearchColField>
              <SearchColField>
                <SearchLabel htmlFor="search_user">User:</SearchLabel>
                <SearchField>
                  <Field
                    component={TextInput}
                    name="search_user"
                    placeholder="Enter User details/ID"
                  />
                </SearchField>
              </SearchColField>
            </SearchRow>
            <FilterSort>
              <FilterSortItem>
                <label htmlFor="date">Date:</label>
                <Field
                  className="input-sort-date"
                  component={TextInput}
                  name="date"
                  type="date"
                />
              </FilterSortItem>
              <FilterSortItem>
                <label htmlFor="action">Action taken:</label>
                <Field
                  name="action"
                  render={({ input }) => (
                    <Dropdown input={input} options={ActionTakenOptions} />
                  )}
                />
              </FilterSortItem>
              <FilterSortItem>
                <PrimaryButton disabled={submitting || pristine} type="submit">
                  Search
                </PrimaryButton>
                {!pristine && (
                  <>
                    &nbsp;&nbsp;
                    <SecondaryButton
                      onClick={() => {
                        handleFilterReset(form.reset);
                      }}
                      type="button"
                    >
                      Clear
                    </SecondaryButton>
                  </>
                )}
              </FilterSortItem>
            </FilterSort>
          </form>
        )}
      />

      <Sortable field={["id"]}>
        {({ field, order, setSort }) => (
          <Pagination filter={filter} perPage={1}>
            {({ page, setPage, perPage }) => {
              const getOrder = (fieldName) => {
                return field.includes(fieldName) ? (order === 1 ? -1 : 1) : 1;
              };
              return (
                <>
                  <Table>
                    <Thead>
                      <Tr>
                        <SortableTh
                          handleClick={() =>
                            setSort({
                              field: ["status"],
                              order: getOrder("status"),
                            })
                          }
                          include={field.includes("status")}
                          order={order}
                        >
                          Date
                        </SortableTh>
                        <Th>Action taken</Th>
                        <Th>Action&nbsp;description</Th>
                        <Th>Property</Th>
                        <Th>User</Th>
                      </Tr>
                    </Thead>
                    <Tbody>
                      <Tr>
                        <Td>
                          06 Aug 2019
                          <br />
                          11:51:00
                        </Td>
                        <Td>
                          Property{" "}
                          <Link className="link" to={``}>
                            PropertyId
                          </Link>
                          <br />
                          unpublished from Mashroom
                        </Td>
                        <Td>
                          <b>Published -&gt; Unpublished</b>
                        </Td>
                        <Td>
                          Barone Court Road, LONDON, <br />
                          <b>ID1 1QD</b>
                        </Td>
                        <Td>
                          <Link className="link" to={``}>
                            Admin Name
                          </Link>
                        </Td>
                      </Tr>
                      <Tr>
                        <Td>
                          06 Aug 2019
                          <br />
                          11:51:00
                        </Td>
                        <Td>
                          Property{" "}
                          <Link className="link" to={``}>
                            PropertyId
                          </Link>
                          <br />
                          published on Mashroom
                        </Td>
                        <Td>
                          <b>Verified -&gt; Published</b>
                        </Td>
                        <Td>
                          Barone Court Road, LONDON, <br />
                          <b>ID1 1QD</b>
                        </Td>
                        <Td>
                          <Link className="link" to={``}>
                            Admin Name
                          </Link>
                        </Td>
                      </Tr>
                      <Tr>
                        <Td>
                          06 Aug 2019
                          <br />
                          11:51:00
                        </Td>
                        <Td>
                          Property{" "}
                          <Link className="link" to={``}>
                            PropertyId
                          </Link>
                          <br />
                          verified
                        </Td>
                        <Td>
                          <b>Unverified -&gt; Verified</b>
                        </Td>
                        <Td>
                          Barone Court Road, LONDON, <br />
                          <b>ID1 1QD</b>
                        </Td>
                        <Td>
                          <Link className="link" to={``}>
                            Admin Name
                          </Link>
                        </Td>
                      </Tr>
                      <Tr>
                        <Td>
                          06 Aug 2019
                          <br />
                          11:51:00
                        </Td>
                        <Td>
                          Property{" "}
                          <Link className="link" to={``}>
                            PropertyId
                          </Link>
                          <br />
                          published on Zoopla
                        </Td>
                        <Td>
                          <b>Verified -&gt; Published</b>
                        </Td>
                        <Td>
                          Barone Court Road, LONDON, <br />
                          <b>ID1 1QD</b>
                        </Td>
                        <Td>
                          <Link className="link" to={``}>
                            Admin Name
                          </Link>
                        </Td>
                      </Tr>
                    </Tbody>
                  </Table>

                  <Pagebar
                    changePage={setPage}
                    curPage={page}
                    showNPages={3}
                    total={Math.ceil(12) / perPage}
                  />
                </>
              );
            }}
          </Pagination>
        )}
      </Sortable>
    </>
  );
};

export default List;
