import React from "react";

import format from "date-fns/format";
import { Link } from "react-router-dom";

import { property_api_PropertyStatusEnum as PropertyStatusEnum } from "../../globalTypes";
import EmailLink from "../../ui/atoms/EmailLink";
import { NoWrap, Td, Tr } from "../../ui/atoms/Table";
import { getExternalPropertyUrl } from "../../util/urls";
import {
  PropertiesList_admin_allProperties_data_location,
  PropertiesList_admin_allProperties_data_people_landlord,
} from "./graphql/queries/__generated__/PropertiesList";
import ListItemStatus from "./ListItemStatus";

type ListItemProps = {
  created: string;
  expires: string;
  propertyId: string;
  landlord: PropertiesList_admin_allProperties_data_people_landlord & {};
  location: PropertiesList_admin_allProperties_data_location & {};
  status: PropertyStatusEnum;
};

const ListItem = ({
  created,
  expires,
  propertyId,
  landlord,
  location,
  status,
}: ListItemProps) => {
  return (
    <Tr>
      <Td colSpan={1} title={propertyId}>
        ...{propertyId.slice(-5)}
      </Td>
      <Td colSpan={2}>{formatStringDate(created)}</Td>
      <Td colSpan={2}>{formatStringDate(expires)}</Td>
      <Td colSpan={3}>
        <b>
          {landlord.details?.first_name}
          &nbsp;
          {landlord.details?.last_name}
        </b>
        {landlord.contact?.email_primary && (
          <NoWrap title={landlord.contact.email_primary}>
            <EmailLink href={`mailto:${landlord.contact.email_primary ?? ""}`}>
              {landlord.contact.email_primary}
            </EmailLink>
          </NoWrap>
        )}
        {landlord.contact?.phone_primary && (
          <div>{landlord.contact.phone_primary}</div>
        )}
      </Td>
      <Td colSpan={3}>
        {[
          location.address1,
          location.address2,
          location.address3,
          location.address4,
        ]
          .filter(Boolean)
          .join(", ")}
        {location.city && (
          <div>
            <b>{location.city}</b>
          </div>
        )}
        {location.postcode && (
          <div>
            <b>{location.postcode}</b>
          </div>
        )}
      </Td>
      <Td colSpan={2}>
        <ListItemStatus status={status} />
      </Td>
      <Td colSpan={1}>
        <Link className="link" to={`/listing/${propertyId}/edit`}>
          Edit
        </Link>
      </Td>
      <Td colSpan={1}>
        <a
          className="link"
          href={getExternalPropertyUrl(propertyId)}
          rel="noopener noreferrer"
          target="_blank"
        >
          Open
        </a>
      </Td>
    </Tr>
  );
};

export default ListItem;

const formatStringDate = (date?: string | null): JSX.Element => {
  return (
    <>
      {date ? format(new Date(date), "dd MMM yyyy") : "- - -"}
      {date ? <div>{format(new Date(date), "HH:mm:ss")}</div> : null}
    </>
  );
};
