import React, { FC } from "react";

import { sentenceCase } from "change-case";

import { property_api_PropertyStatusEnum as PropertyStatusEnum } from "../../globalTypes";
import {
  StatusActive,
  StatusIncomplete,
  StatusListed,
  StatusUnknown,
  StatusVerifying,
} from "../../ui/atoms/Status";

type Props = {
  status: PropertyStatusEnum;
};

const ListItemStatus: FC<Props> = ({ status }) => {
  const text = sentenceCase(status);
  return (
    <>
      {status === PropertyStatusEnum.UNKNOWN_STATUS ||
      status === PropertyStatusEnum.WITHDRAWN ? (
        <StatusUnknown>{text}</StatusUnknown>
      ) : status === PropertyStatusEnum.ACTIVE ? (
        <StatusActive>{text}</StatusActive>
      ) : status === PropertyStatusEnum.LISTED ||
        status === PropertyStatusEnum.OFFERING ||
        status === PropertyStatusEnum.RENTED ||
        status === PropertyStatusEnum.RENT_COLLECTION ? (
        <StatusListed>{text}</StatusListed>
      ) : status === PropertyStatusEnum.VERIFYING ||
        status === PropertyStatusEnum.MISSING ||
        status === PropertyStatusEnum.AMENDMENT ? (
        <StatusVerifying>{text}</StatusVerifying>
      ) : (
        <StatusIncomplete>{text}</StatusIncomplete>
      )}
    </>
  );
};

export default ListItemStatus;
