import React, { useCallback } from "react";

import { useMutation, useQuery } from "react-apollo";

import ButtonText from "../../ui/atoms/ButtonText";
import { ModalConfirm } from "../../ui/molecules/Modal";
import { UpdateProperty_admin_updateProperty_description } from "./graphql/mutations/__generated__/UpdateProperty";
import {
  UpdatePropertyDescription,
  UpdatePropertyDescriptionVariables,
} from "./graphql/mutations/__generated__/UpdatePropertyDescription";
import UPDATE_PROPERTY_DESCRIPTION from "./graphql/mutations/UpdatePropertyDescription.graphql";
import {
  GetProperty,
  GetProperty_admin_Property_description_photos,
  GetPropertyVariables,
} from "./graphql/queries/__generated__/GetProperty";
import GET_PROPERTY from "./graphql/queries/GetProperty.graphql";

type Props = {
  item: GetProperty_admin_Property_description_photos;
  propertyId: string;
};
type DescriptionType = Pick<
  UpdateProperty_admin_updateProperty_description,
  "post_area_pitch" | "post_comment" | "post_headline" | "post_property_pitch"
> & {
  photos: string[];
  plans: string[];
};
export default function PhotoDeleteForm({ item, propertyId }: Props) {
  const [state, setState] = React.useState(false);

  const { data: propertyData } = useQuery<GetProperty, GetPropertyVariables>(
    GET_PROPERTY,
    {
      variables: { id: propertyId },
    }
  );

  const [updatePropertyDescription] = useMutation<
    UpdatePropertyDescription,
    UpdatePropertyDescriptionVariables
  >(UPDATE_PROPERTY_DESCRIPTION, {
    refetchQueries: ["GetProperty", "GetAllDocuments"],
  });
  function open() {
    setState(true);
  }
  function close() {
    setState(false);
  }
  const handleDelete = useCallback(() => {
    const photos = propertyData?.admin?.Property?.description.photos?.filter(
      (el) => el.id !== item.id
    );
    const plans = propertyData?.admin?.Property?.description.plans?.filter(
      (el) => el.id !== item.id
    );
    const d = propertyData?.admin?.Property?.description;

    const description: DescriptionType = {
      post_area_pitch: d?.post_area_pitch || null,
      post_comment: d?.post_comment || null,
      post_headline: d?.post_headline || null,
      post_property_pitch: d?.post_area_pitch || null,
      photos: [...(photos ? photos : []).map((i) => i.id)],
      plans: [...(plans ? plans : []).map((i) => i.id)],
    };
    try {
      updatePropertyDescription({
        variables: {
          description,
          id: propertyId,
        },
      }).then((response) => {
        if (!response?.data?.admin?.updateProperty?.id) {
          window && alert("Something went wrong. Please, try more later.");
        }
      });
      close();
    } catch (error) {
      window && alert(String(error));
    }
  }, [item.id, propertyId, updatePropertyDescription, propertyData]);

  return (
    <>
      <ButtonText onClick={open} type="button">
        Delete
      </ButtonText>
      {state && (
        <ModalConfirm onCancel={close} onConfirm={handleDelete}>
          <strong>Are you sure you want to delete this photo?</strong>
        </ModalConfirm>
      )}
    </>
  );
}
