import React, { Fragment } from "react";

import LinkWithPreviewFile from "../../ui/atoms/LinkWithPreviewFile";
import {
  TdInner,
  TdInnerWidth20,
  TdInnerWidth30,
  TrInner,
} from "../../ui/atoms/Table";
import { formatDateTime } from "../../util/date";
import { GetProperty_admin_Property_description_photos } from "./graphql/queries/__generated__/GetProperty";
import PhotoDeleteForm from "./PhotoDeleteForm";

type Props = {
  item: GetProperty_admin_Property_description_photos;
  type: "Photo" | "Plan";
  withoutParent?: boolean;
  propertyId: string;
};

const PhotosRow: React.FC<Props> = ({
  item,
  type,
  withoutParent,
  propertyId,
}) => {
  const Parent = withoutParent ? Fragment : TrInner;
  return (
    <Parent>
      <TdInnerWidth30>
        <LinkWithPreviewFile
          href={`/media/${item.id}`}
          rel="noopener noreferrer"
          target="_blank"
          title={item.name}
        >
          <img alt="" src={`/media/thumb-${item.id}`} />
          <span>
            {item.name.length > 22 ? (
              <>
                {item.name.substring(0, 6)}
                &nbsp;&hellip;&nbsp;
                {item.name.substr(-16)}
              </>
            ) : (
              item.name
            )}
          </span>
        </LinkWithPreviewFile>
      </TdInnerWidth30>
      <TdInner>
        <b>{type}</b>
      </TdInner>
      <TdInner>{item.description}</TdInner>
      <TdInnerWidth20>{formatDateTime(item.created_at)}</TdInnerWidth20>
      <TdInner>
        <PhotoDeleteForm item={item} propertyId={propertyId} />
      </TdInner>
    </Parent>
  );
};

export default PhotosRow;
