import React, { FC, useMemo } from "react";

import { PropertyHeader, PropertyPhoto } from "../../ui/atoms/Property";
import PropertyPhotoPlaceholder from "../../ui/atoms/PropertyPhotoPlaceholder";
import { GetProperty_admin_Property } from "./graphql/queries/__generated__/GetProperty";
import PropertyCard from "./PropertyCard";
import PropertyStatuses from "./PropertyStatuses";

type Props = {
  property: GetProperty_admin_Property;
};

const PropertyHead: FC<Props> = ({ property }) => {
  const propertyImage = useMemo(() => {
    const propertyPhotos =
      property.description.photos?.filter((p) => !p.deleted_on) ?? [];
    return propertyPhotos.length > 0
      ? `/media/thumb-${propertyPhotos[0].id}`
      : undefined;
  }, [property.description.photos]);

  return (
    <PropertyHeader>
      {propertyImage ? (
        <PropertyPhoto alt="" src={propertyImage} />
      ) : (
        <PropertyPhotoPlaceholder />
      )}
      <PropertyCard property={property} />
      <PropertyStatuses />
    </PropertyHeader>
  );
};

export default PropertyHead;
