import React from "react";

import styled from "@emotion/styled";
import { Field } from "react-final-form";

import FormAsideAdminUser from "../../components/FormAsideAdminUser";
import { property_api_PropertyStatusEnum as PropertyStatusEnum } from "../../globalTypes";
import { PrimaryButton } from "../../ui/atoms/Button";
import { Gap100 } from "../../ui/atoms/Gap";
import {
  PropertyAside,
  PropertyAsideButtons,
  PropertyVerifiedBlock,
} from "../../ui/atoms/Property";
import { UserFormRow } from "../../ui/atoms/UserForm";
import { CheckboxToggle } from "../../ui/molecules/CheckboxToggle";
import FormPhotoAdd from "./FormPhotoAdd";
import { GetProperty_admin_Property } from "./graphql/queries/__generated__/GetProperty";
import { PropertyAdminVefiry } from "./graphql/queries/__generated__/PropertyAdminVefiry";
import VerifyContext from "./PropertyEditContext";
import PropertyVerificationButtons from "./PropertyVerificationButtons";

type Props = {
  adminVerify: PropertyAdminVefiry;
  verifyKey: string;
  children?: JSX.Element;
  isVerified: boolean;
  verifiedName: string;
  verifiedLabel: string;
  hasEmptySpace?: boolean;
  property: GetProperty_admin_Property;
  onPhotosEdit?: () => void;
  onPhotosOrderUpdate?: () => void;
  propertyStatus?: PropertyStatusEnum;
  disabled?: boolean;
  showVerifiedButtons?: boolean;
};

const PropertyVerification = (props: Props) => (
  <VerifyContext.Consumer>
    {({ publishedInMashroom, submitting, photosVerified }) => (
      <PropertyAside>
        <PropertyVerifiedBlock>
          <UserFormRow>
            <Field
              component={CheckboxToggle}
              data-testid="4odajg5rvrmpq"
              disabled={
                submitting ||
                (publishedInMashroom &&
                  props.property.status !== PropertyStatusEnum.VERIFYING)
              }
              labelText={props.verifiedLabel}
              name={props.verifiedName}
              type="checkbox"
            />
          </UserFormRow>
          {props.adminVerify[props.verifyKey].admin && (
            <FormAsideAdminUser
              date={props.adminVerify[props.verifyKey].verified_at}
              id={props.adminVerify[props.verifyKey].admin}
            />
          )}
          {props.disabled ? <Overlay /> : null}
        </PropertyVerifiedBlock>

        {photosVerified &&
          props.verifyKey === "photos" &&
          props.property.status !== PropertyStatusEnum.INCOMPLETE &&
          props.property.status !== PropertyStatusEnum.ACTIVE &&
          props.onPhotosEdit != null && (
            <PropertyAsideButtons>
              <PrimaryButton onClick={props.onPhotosEdit} type="button">
                Edit
              </PrimaryButton>
            </PropertyAsideButtons>
          )}

        {props.verifyKey === "photos" ? (
          <PropertyAsideButtons>
            <FormPhotoAdd property={props.property} type="addPhoto" />
            <FormPhotoAdd property={props.property} type="addPlan" />
          </PropertyAsideButtons>
        ) : null}

        {props.showVerifiedButtons ||
        props.isVerified ||
        (publishedInMashroom &&
          props.property.status === PropertyStatusEnum.VERIFYING) ||
        (!publishedInMashroom && !props.showVerifiedButtons) ? (
          <PropertyVerificationButtons
            onPhotosOrderUpdate={props.onPhotosOrderUpdate}
            tabName={props.verifyKey}
          />
        ) : null}

        {props.hasEmptySpace && <Gap100 />}
        {props.children}
      </PropertyAside>
    )}
  </VerifyContext.Consumer>
);

const Overlay = styled.div`
  position: absolute;
  left: -10px;
  top: -10px;
  right: -10px;
  bottom: -10px;
  z-index: 5;
  background: #f5f5f699;
`;

export default PropertyVerification;
