// import EmailLink from "../../../ui/atoms/EmailLink";
import React, { FC } from "react";

import styled from "@emotion/styled";
import { sentenceCase } from "change-case";
import format from "date-fns/format";
import { Link } from "react-router-dom";
import { oc } from "ts-optchain";

import { Td, TdWidth25, Tr } from "../../../ui/atoms/Table";
import { formatDateTime } from "../../../util/date";
import { timeFromNumber } from "../../offers/utils";
import { MOVEIN_DATE } from "../constants";
import { GetProperty_admin_Property_viewings as Property_viewings } from "../graphql/queries/__generated__/GetProperty";

type Props = { viewing: Property_viewings };

const TabViewingItem: FC<Props> = ({
  viewing: {
    details: { movein_date },
    accepted_at,
    created_at,
    feedback,
    sender,
    sender_details,
    time,
    status,
  },
}) => (
  <Tr>
    <Td>
      {sender ? (
        <Link className="link" to={`/users/${sender}/view`}>
          {sender_details.first_name}
          &nbsp;
          {sender_details.last_name}
        </Link>
      ) : (
        <>
          {sender_details.first_name}
          &nbsp;
          {sender_details.last_name}
        </>
      )}
      {/* {sender.email_primary && (
        <>
          <br />
          <EmailLink href={`mailto:${sender.email_primary}`}>
            {sender.email_primary}
          </EmailLink>
        </>
      )} */}
      {sender_details.phone && (
        <div>
          <strong>{sender_details.phone}</strong>
        </div>
      )}
    </Td>
    <Td>{formatDateTime(created_at)}</Td>
    <Td>{formatDateTime(accepted_at)}</Td>
    <Td>
      {format(
        new Date(
          time.year as number,
          (time.month as number) - 1,
          time.day as number
        ),
        "dd MMM yyyy"
      )}
      <br />
      {timeFromNumber(time.time_startsec as number)} –{" "}
      {timeFromNumber(time.time_endsec as number)}
    </Td>
    <Td>{MOVEIN_DATE[movein_date]}</Td>
    <TdWidth25>
      {oc(
        (feedback ? feedback : []).filter((f) => f.comment !== "")
      )[0].comment()}
    </TdWidth25>
    <TdStatus>
      {sentenceCase(status.toString().replace("VIEWING_STATE_", ""))}
    </TdStatus>
  </Tr>
);

const TdStatus = styled(Td)`
  text-transform: capitalize;
  font-weight: 700;
`;

export default TabViewingItem;
