import { sentenceCase } from "change-case";
import { oc } from "ts-optchain";

import {
  document_api_DocumentTypeEnum,
  property_api_PropertyTypeEnum,
} from "../../../globalTypes";
import {
  GetProperty_admin_Property,
  GetProperty_admin_Property_location as PropertyLocation,
} from "../graphql/queries/__generated__/GetProperty";

export const propertyAddressFilter = (
  location: Pick<
    PropertyLocation,
    "flat" | "building" | "street" | "city" | "postcode" | "country"
  >
): string => {
  const { flat, building, street, city, postcode, country } = location;

  return [flat, building, street, city, postcode, country]
    .filter(Boolean)
    .join(", ");
};

export const propertyTitleFilter = (
  property: NonNullable<GetProperty_admin_Property>
): string => {
  let output: string;

  if (oc(property).details.bedrooms_no(0) > 0) {
    output = `${property.details.bedrooms_no} Bedroom ${propertyTypeFilter(
      property.details.type
    )}`;
  } else {
    output = propertyTypeFilter(property.details.type);
  }
  output += ` in ${property.location.address1}`;

  return output;
};

export const propertyTypeFilter = (
  value: property_api_PropertyTypeEnum
): string => {
  switch (value) {
    case "PROPERTY_TYPE_STUDIO":
      return "Studio";
    case "PROPERTY_TYPE_FLAT":
      return "Flat";
    case "PROPERTY_TYPE_DETACHED":
      return "Detached";
    case "PROPERTY_TYPE_SEMI_DETACHED":
      return "Semi detached";
    case "PROPERTY_TYPE_TERRACED":
      return "Terraced";
    case "PROPERTY_TYPE_OTHER":
      return "Other";
    case "PROPERTY_TYPE_MAISONETTE":
      return "Maisonette";
    case "PROPERTY_TYPE_BUNGALOW":
      return "Bungalow";
    case "PROPERTY_TYPE_TOWN_HOUSE":
      return "Townhouasdfsadfse";
    case "PROPERTY_TYPE_COTTAGE":
      return "Cottage";
    case "PROPERTY_TYPE_APARTMENT":
      return "Apartment";
    case "PROPERTY_TYPE_PENTHOUSE":
      return "Penthouse";
    case "PROPERTY_TYPE_PARK_HOME":
      return "Park home";
    default:
      return value;
  }
};

export const documentTypeFilter = (
  type: document_api_DocumentTypeEnum,
  code: string
): string => {
  if (type === document_api_DocumentTypeEnum.CERTIFICATE) {
    switch (code) {
      case "landlord_epc_certificate":
        return "EPC";
      case "landlord_gas_certificate":
        return "Gas Safety";
      case "landlord_eic_report":
        return "EICR";
      default:
        return "Unknown";
    }
  } else {
    return sentenceCase(type);
  }
};

export const feeTypeFilter = (type: string): string => {
  switch (type) {
    case "INVENTORY_REPORT":
      return "Inventory Report";
    case "RENT":
      return "Rent";
    case "BUNDLE":
      return "Bundle";
    case "CHECK_OUT_REPORT":
      return "Check out Report";
    case "CERTIFICATE":
      return "Certificate";
    case "CHECK_IN_REPORT":
      return "Check in Report";
    case "ADVANCED_RENT_PLAN":
      return "Advanced Rent Plan";
    case "DEPOSIT":
      return "Deposit";
    case "DEPOSIT_INSURANCE":
      return "Deposit Insurance";
    case "RENT_GUARANTEE_INSURANCE":
      return "Rent Guarantee Insurance";
    default:
      return "Unknown Service Type";
  }
};

export const feeStatusFilter = (status: string): string => {
  switch (status) {
    case "UNPAID":
      return "Unpaid";
    case "PROCESSING":
      return "Processing";
    case "SUCCEEDED":
      return "Succeeded";
    case "FAILED":
      return "Failed";
    case "CANCELLED":
      return "Cancelled";
    default:
      return "Unknown Payment Status";
  }
};
