import React from "react";

import { Field, Form } from "react-final-form";

import { PrimaryButton, SecondaryButton } from "../../../../../ui/atoms/Button";
import { InputField } from "../../../../../ui/molecules/InputField";
import { required } from "../../../../../util/validations";

import css from "./index.module.css";

type Props = {
  onClose: () => void;
};

const EditLead = ({ onClose }: Props) => {
  const handleSubmit = ({ lead }) => {
    onClose();
  };
  return (
    <Form
      onSubmit={handleSubmit}
      render={({ handleSubmit }) => {
        return (
          <form onSubmit={handleSubmit}>
            <div className={css.formRow}>
              <div className={css.inputGroup}>
                <label htmlFor="lead.name">Full name</label>
                <Field
                  component={InputField}
                  name={"lead.name"}
                  validate={required("Name is require field")}
                />
              </div>
              <div className={css.inputGroup}>
                <label htmlFor="lead.name">Email</label>
                <Field
                  component={InputField}
                  name={"lead.email"}
                  validate={required("Email is require field")}
                />
              </div>
            </div>
            <div className={css.formRow}>
              <div className={css.inputGroup}>
                <label htmlFor="lead.earnings">Earnings</label>
                <Field component={InputField} name="lead.earnings" />
              </div>
              <div className={css.inputGroup}>
                <label htmlFor="lead.relationship">Relationship status</label>
                <Field
                  component={InputField}
                  name="lead.assigned_to"
                  validate={required("Assigned to is require field")}
                />
              </div>
            </div>
            <div className={css.formRow}>
              <div className={css.inputGroup}>
                <label htmlFor="lead.phone">Phone</label>
                <Field component={InputField} name="lead.phone" />
              </div>
            </div>
            <div className={css.buttonWrapper}>
              <PrimaryButton type="submit">Save</PrimaryButton>
              <SecondaryButton onClick={onClose} type="button">
                Cancel
              </SecondaryButton>
            </div>
          </form>
        );
      }}
    />
  );
};

export default EditLead;
