import React, { useState } from "react";

import { PrimaryButton } from "../../../ui/atoms/Button";
import { ModalWide } from "../../../ui/molecules/Modal";
import Tabs from "../../../ui/molecules/Tabs";
import EditLead from "./components/EditLead";
import LeadTabContent from "./components/LeadTabContent";

import css from "./index.module.css";

const TABS = ["Deals", "Documents"];

const lead = {
  name: "Alex Deal",
  email: "mail@mail.com",
  phone: "+44 435 231 12 34",
  mrmlink: "https://mashroom.com",
  earnings: 35000,
  relationStatus: "married",
};
const LeadEdit: React.FC = () => {
  const [isEditModalOpen, setIsEditModalOpen] = useState(false);

  const handleEditClick = () => {
    setIsEditModalOpen(true);
  };
  const handleEditModalClose = () => {
    setIsEditModalOpen(false);
  };
  return (
    <>
      <div className={css.header}>
        <div className={css.info}>
          <div className={css.headerBlock}>
            <span className={css.infoHeader}> Name</span>
            <span> {lead.name}</span>
          </div>
          <div className={css.headerBlock}>
            <span className={css.infoHeader}> Email</span>
            <span> {lead.email}</span>
          </div>
          <div className={css.headerBlock}>
            <span className={css.infoHeader}>Phone</span>
            <span> {lead.phone}</span>
          </div>
          <div className={css.headerBlock}>
            <span className={css.infoHeader}>Mashroom link</span>
            <span> {lead.mrmlink}</span>
          </div>
          <div className={css.headerBlock}>
            <span className={css.infoHeader}>Earnings</span>
            <span> {lead.earnings}</span>
          </div>
          <div className={css.headerBlock}>
            <span className={css.infoHeader}>Relationship status</span>
            <span> {lead.relationStatus}</span>
          </div>
        </div>
        <div className={css.actions}>
          <PrimaryButton onClick={handleEditClick} type={"button"}>
            Edit lead details
          </PrimaryButton>
          <PrimaryButton>Upload document</PrimaryButton>
        </div>
      </div>
      <Tabs>
        {({ curTabIndex, setTab, TabList, TabItem, TabActive, TabBody }) => {
          return (
            <>
              <TabList>
                {TABS.map((tab, index) => {
                  if (index === curTabIndex) {
                    return <TabActive key={tab}>{tab}</TabActive>;
                  }
                  return (
                    <TabItem key={tab} onClick={() => setTab(index)}>
                      {tab}
                    </TabItem>
                  );
                })}
              </TabList>
              <TabBody>
                <LeadTabContent currentTab={curTabIndex} />
              </TabBody>
            </>
          );
        }}
      </Tabs>
      {isEditModalOpen && (
        <ModalWide
          onCancel={handleEditModalClose}
          title={"Edit Lead"}
          width={800}
        >
          <EditLead onClose={handleEditModalClose} />
        </ModalWide>
      )}
    </>
  );
};

export default LeadEdit;
