import React, { useState } from "react";

import { Th, Tr } from "../../../../../ui/atoms/Table";
import SortableTh from "../../../../../ui/molecules/SortableTh";

type Props = {
  onSortChange: (field: string, order: number) => void;
};
const TableHeader = ({ onSortChange }: Props) => {
  const [rows, setRows] = useState([
    {
      name: "Full name",
      field: "name",
      sortable: true,
      order: 1,
    },
    {
      field: "created",
      name: "Date Added",
      sortable: true,
      order: 1,
    },
    {
      field: "email",
      name: "Email",
      sortable: true,
      order: 1,
    },
    {
      field: "assigned_to",
      name: "Assigned to",
      sortable: true,
      order: 1,
    },
    {
      field: "stage",
      name: "Stage",
      sortable: false,
    },
    {
      field: "",
      name: "",
      sortable: false,
    },
  ]);

  return (
    <Tr>
      {rows.map((row) => {
        const handleSortClick = () => {
          if (row.sortable) {
            onSortChange(row.field, row.order === 1 ? -1 : 1);
            setRows((prevState) =>
              prevState.map((el) =>
                el.name === row.name
                  ? {
                      ...el,
                      order: el.order === 1 ? -1 : 1,
                    }
                  : el
              )
            );
          }
        };
        return row.sortable ? (
          <SortableTh
            handleClick={handleSortClick}
            include={true}
            order={row.order}
          >
            {row.name}
          </SortableTh>
        ) : (
          <Th>{row.name}</Th>
        );
      })}
    </Tr>
  );
};

export default TableHeader;
