import React, { memo } from "react";

import { format } from "date-fns";
import { NavLink, useRouteMatch } from "react-router-dom";

import { Td, Tr } from "../../../../../ui/atoms/Table";
import { AllLeads_admin_mortgageAllLeads_leads as Lead } from "../../../graphql/queries/__generated__/AllLeads";
import { stageTranslate } from "../../utils";

type Props = {
  lead: Lead;
};

const LeadRow = memo(({ lead }: Props) => {
  const { url } = useRouteMatch();
  return (
    <Tr key={lead.id}>
      <Td>{lead.name}</Td>
      <Td>{format(new Date(lead.created), "dd/MM/yy")} </Td>
      <Td>
        <a href={`mailto:${lead.email}`}>{lead.email}</a>
      </Td>
      <Td>{lead.assigned_to}</Td>
      <Td>{stageTranslate(lead.stage)}</Td>
      <Td>
        <NavLink to={`${url}/${lead.id}/edit`}>View</NavLink>
      </Td>
    </Tr>
  );
});

export default LeadRow;
