import { ValueOf } from "ts-essentials";

import {
  Notification_Api_CategoryEnum,
  Notification_Api_EventChannelEnum,
  Notification_Api_RoleEnum,
} from "../../graphql-schema-types.generated";

export type ConvertEnum<T> = {
  label: string;
  value: T;
};

const convertEnum = <T extends {}>(
  prefix: string,
  originEnum: T
): Array<ConvertEnum<ValueOf<T>>> =>
  Object.entries<ValueOf<T>>(originEnum).reduce<Array<ConvertEnum<ValueOf<T>>>>(
    (acc, [key, value]) => [...acc, { label: prettify(key, prefix), value }],
    []
  );

const prettify = (key: string, prefix: string): string => {
  return key.replace(prefix, "");
};

export const findElement = <T extends {}>(
  source: Array<ConvertEnum<ValueOf<T>>>,
  value: ValueOf<T>
): ConvertEnum<ValueOf<T>> =>
  source.find((e) => e.value === value) || { label: " ", value };

export const isElement = <T extends {}>(
  current: ConvertEnum<T>,
  value: T
): boolean => current.value === value;

export const CategoryOptions = convertEnum(
  "Category",
  Notification_Api_CategoryEnum
);

export const ChannelOptions = convertEnum(
  "EventChannel",
  Notification_Api_EventChannelEnum
);

export const TargetRoleOptions = convertEnum("Role", Notification_Api_RoleEnum);

export const defaultNotification = {
  ID: 0,
  category: Notification_Api_CategoryEnum.CategoryUnknown,
  channel: Notification_Api_EventChannelEnum.UnknownEventChannel,
  target: Notification_Api_RoleEnum.RoleUnknown,
  template: "",
  escape_html: true,
  seconds: 0,
  nanos: 0,
  disabled: false,
  data: {},
};
