import React, { useMemo } from "react";

import { useQuery } from "react-apollo";
import { RouteComponentProps } from "react-router-dom";

import { OfferCardItemTitle } from "../../ui/atoms/Offer";
import Spinner from "../../ui/atoms/Spinner";
import SystemError from "../../ui/atoms/SystemError";
import Tabs from "../../ui/molecules/Tabs";
import { TABS } from "./constants";
import {
  GetOffer,
  GetOfferVariables,
} from "./graphql/queries/__generated__/GetOffer";
import GET_OFFER from "./graphql/queries/GetOffer.graphql";
import OfferHead from "./OfferHead";
import OfferTabContent from "./OfferTabContent";

type ParamsProps = {
  id?: string;
};
type Props = RouteComponentProps<ParamsProps>;

const Edit = (props: Props) => {
  const offerId = props.match.params.id;

  const { data, loading, error, refetch } = useQuery<
    GetOffer,
    GetOfferVariables
  >(GET_OFFER, {
    variables: {
      id: offerId,
    },
    pollInterval: 20000,
  });

  const offer = data?.admin?.Offer;

  const needRentProfileCheck = useMemo(
    () => offer?.tenants?.some((tenant) => !!tenant.check) ?? false,
    [offer]
  );

  if (error) {
    return <SystemError error={error} />;
  }

  if (!data && loading) {
    return <Spinner />;
  }

  if (!offer) {
    return null;
  }

  return (
    <>
      <OfferHead offer={offer} />
      <OfferCardItemTitle>
        Referencing method:{" "}
        {needRentProfileCheck ? "Rentprofile" : "Manual check by Landlord"}
      </OfferCardItemTitle>
      <Tabs defaultTab={0}>
        {({ curTabIndex, setTab, TabList, TabItem, TabActive, TabBody }) => {
          return (
            <>
              <TabList>
                {TABS.map((tab, index) => {
                  if (index === curTabIndex) {
                    return <TabActive key={tab}>{tab}</TabActive>;
                  }

                  return (
                    <TabItem key={tab} onClick={() => setTab(index)}>
                      {tab}
                    </TabItem>
                  );
                })}
              </TabList>
              <TabBody>
                <OfferTabContent
                  curTabIndex={curTabIndex}
                  offer={offer}
                  refetchOffer={refetch}
                />
              </TabBody>
            </>
          );
        }}
      </Tabs>
    </>
  );
};

export default Edit;
