import React, { useCallback } from "react";

import { notification } from "antd";
import AntdButton from "antd-button-color";

import { NOTIFICATION_DURATION } from "../../../constants/notifications";
import { useGenerateRentPlanInsurancesMutation } from "../hooks/useGenerateRentPlanInsurances";
import { getErrorMessageFromGraphQLError } from "../utils/getErrorMessageFromGraphQLError";
import { NOTIFICATION_TITLE } from "./constants";
import { GenerateDocumentsButtonProps } from "./types";

export const GenerateDocumentsButton = ({
  offerId,
}: GenerateDocumentsButtonProps) => {
  const [
    generateRentPlanInsurancesMutation,
    { loading },
  ] = useGenerateRentPlanInsurancesMutation();

  const handleButtonClick = useCallback(async () => {
    const { data, errors } = await generateRentPlanInsurancesMutation({
      variables: {
        offerId,
      },
    });

    if (data?.admin?.generateRentPlanInsurances) {
      notification.open({
        description: "Documents have been generated",
        duration: NOTIFICATION_DURATION,
        message: NOTIFICATION_TITLE,
        type: "success",
      });
    }

    if (errors?.length) {
      notification.open({
        description: getErrorMessageFromGraphQLError(errors),
        duration: NOTIFICATION_DURATION,
        message: NOTIFICATION_TITLE,
        type: "error",
      });
    }
  }, [generateRentPlanInsurancesMutation, offerId]);

  return (
    <AntdButton
      disabled={loading}
      loading={loading}
      onClick={handleButtonClick}
      type="default"
    >
      Generate documents
    </AntdButton>
  );
};
