import React, { useCallback } from "react";

import { notification } from "antd";
import AntdButton from "antd-button-color";

import { NOTIFICATION_DURATION } from "../../../constants/notifications";
import { useGenerateRentInvoicesMutation } from "../hooks/useGenerateRentInvoices";
import { getErrorMessageFromGraphQLError } from "../utils/getErrorMessageFromGraphQLError";
import { NOTIFICATION_TITLE } from "./constants";
import { GeneratePaymentsButtonProps } from "./types";

export const GeneratePaymentsButton = ({
  offerId,
}: GeneratePaymentsButtonProps) => {
  const [
    generateRentInvoicesMutation,
    { loading },
  ] = useGenerateRentInvoicesMutation();

  const handleButtonClick = useCallback(async () => {
    const { data, errors } = await generateRentInvoicesMutation({
      variables: {
        offerId,
      },
    });

    if (data?.admin?.generateRentInvoices) {
      notification.open({
        description: "Payments have been generated",
        duration: NOTIFICATION_DURATION,
        message: NOTIFICATION_TITLE,
        type: "success",
      });
    }

    if (errors?.length) {
      notification.open({
        description: getErrorMessageFromGraphQLError(errors),
        duration: NOTIFICATION_DURATION,
        message: NOTIFICATION_TITLE,
        type: "error",
      });
    }
  }, [generateRentInvoicesMutation, offerId]);

  return (
    <AntdButton
      disabled={loading}
      loading={loading}
      onClick={handleButtonClick}
      type="default"
    >
      Generate payments
    </AntdButton>
  );
};
