import React from "react";

import format from "date-fns/format";
import { Link } from "react-router-dom";

import EmailLink from "../../ui/atoms/EmailLink";
import { NoWrap, Td, Tr } from "../../ui/atoms/Table";
import {
  OffersList_admin_allOffers_data_landlord as Landlord,
  OffersList_admin_allOffers_data_property as Property,
  OffersList_admin_allOffers_data_tenants as Tenant,
} from "./graphql/queries/__generated__/OffersList";

type ListItemProps = {
  offerId: string;
  initiated: string;
  changed: string;
  stage: string;
  property: Property;
  landlord: Landlord;
  tenant: Tenant | undefined;
};

const ListItem = ({
  offerId,
  initiated,
  changed,
  stage,
  property: {
    id: propertyId,
    location,
    people: { landlord, manager },
  },
  landlord: ll,
  tenant,
}: ListItemProps) => {
  return (
    <Tr>
      <Td colSpan={1}>...{offerId.slice(-5)}</Td>
      <Td colSpan={2}>{format(new Date(initiated), "dd MMM yyyy HH:mm:ss")}</Td>
      <Td colSpan={2}>{format(new Date(changed), "dd MMM yyyy HH:mm:ss")}</Td>
      <Td colSpan={2}>
        <b>{stage}</b>
      </Td>
      <Td colSpan={3}>
        {propertyId ? (
          <div>
            <Link className="link" to={`/listing/${propertyId}/edit`}>
              ...{propertyId.slice(-5)}
            </Link>
          </div>
        ) : (
          "—"
        )}
        {[
          location.address1,
          location.address2,
          location.address3,
          location.address4,
        ]
          .filter(Boolean)
          .join(", ")}
        {location.city && (
          <div>
            <b>{location.city}</b>
          </div>
        )}
        {location.postcode && (
          <div>
            <b>{location.postcode}</b>
          </div>
        )}
      </Td>
      <Td colSpan={3}>
        {landlord?.id ? (
          <b>
            <Link className="link" to={`/users/${landlord.id}/view`}>
              {landlord.details?.first_name}
              &nbsp;
              {landlord.details?.last_name}
            </Link>
          </b>
        ) : ll.first_name !== "" ? (
          <b>
            {ll.first_name}
            &nbsp;
            {ll.last_name}
          </b>
        ) : (
          "—"
        )}
        {ll.email_primary && (
          <NoWrap title={ll.email_primary}>
            <EmailLink href={`mailto:${ll.email_primary}`}>
              {ll.email_primary}
            </EmailLink>
          </NoWrap>
        )}
        {ll.phone_primary && (
          <NoWrap title={ll.phone_primary}>{ll.phone_primary}</NoWrap>
        )}
      </Td>
      <Td colSpan={3}>
        {tenant && (
          <>
            <Link className="link" to={`/users/${tenant.user}/view`}>
              <b>
                {tenant.first_name}
                &nbsp;
                {tenant.last_name}
              </b>
            </Link>
            {tenant.email_primary && (
              <NoWrap title={tenant.email_primary}>
                <EmailLink href={`mailto:${tenant.email_primary}`}>
                  {tenant.email_primary}
                </EmailLink>
              </NoWrap>
            )}
            {tenant.phone_primary && (
              <NoWrap title={tenant.phone_primary}>
                {tenant.phone_primary}
              </NoWrap>
            )}
          </>
        )}
      </Td>
      <Td colSpan={3}>
        {manager && (
          <>
            {manager.id && (
              <b>
                <Link className="link" to={`/users/${manager.id}/view`}>
                  {manager.details?.first_name}
                  &nbsp;
                  {manager.details?.last_name}
                </Link>
              </b>
            )}
            {manager.contact?.email_primary && (
              <NoWrap title={manager.contact.email_primary}>
                <EmailLink href={`mailto:${manager.contact.email_primary}`}>
                  {manager.contact.email_primary}
                </EmailLink>
              </NoWrap>
            )}
            {manager.contact?.phone_primary && (
              <NoWrap title={manager.contact.phone_primary}>
                {manager.contact.phone_primary}
              </NoWrap>
            )}
          </>
        )}
      </Td>
      <Td colSpan={1}>
        <Link className="link" to={`/offers/${offerId}/edit`}>
          View
        </Link>
      </Td>
    </Tr>
  );
};

export default ListItem;
