import React, { FC, useState } from "react";

import styled from "@emotion/styled";

import Notes from "../../components/Notes";
import { offer_api_OfferStateEnum } from "../../globalTypes";
import { PrimaryButton } from "../../ui/atoms/Button";
import { OfferHeader, OfferHeaderRight } from "../../ui/atoms/Offer";
import { GenerateDocumentsButton } from "./GenerateDocumentsButton";
import { GeneratePaymentsButton } from "./GeneratePaymentsButton";
import { GetOffer_admin_Offer } from "./graphql/queries/__generated__/GetOffer";
import OfferCard from "./OfferHeadCard";
import OfferStatuses from "./OfferStatuses";
import PrepareContractModal from "./PrepareContractModal";

type Props = {
  offer: GetOffer_admin_Offer;
};

const OfferHead: FC<Props> = ({ offer }) => {
  const [showModal, setShowModal] = useState(false);

  return (
    <OfferHeader>
      {offer.property?.id ? (
        <NoteBtn>
          <Notes propertyId={offer?.property?.id} title="Property Notes" />
        </NoteBtn>
      ) : null}
      <OfferCard offer={offer} />
      <OfferHeaderRight>
        <OfferStatuses offer={offer} />
        <PrimaryButton
          disabled={
            (offer.state !== offer_api_OfferStateEnum.SIGNING &&
              offer.state !== offer_api_OfferStateEnum.CONTRACT_PREPARATION) ||
            !offer.approve?.approved
          }
          onClick={() => setShowModal(true)}
          type="button"
        >
          Prepare contract
        </PrimaryButton>

        <GenerateDocumentsButton offerId={offer.id} />

        <GeneratePaymentsButton offerId={offer.id} />

        {showModal && (
          <PrepareContractModal
            handleCancel={() => setShowModal(false)}
            offer={offer}
          />
        )}
      </OfferHeaderRight>
    </OfferHeader>
  );
};

const NoteBtn = styled.div`
  right: 270px;
  position: absolute;
  top: 0;
`;

export default OfferHead;
