import React, { Fragment } from "react";

import styled from "@emotion/styled";
import gql from "graphql-tag";
import { useMutation } from "react-apollo";
import { Field, Form } from "react-final-form";

import { PrimaryButton } from "../../ui/atoms/Button";
import Checkbox from "../../ui/molecules/Checkbox";
import { ModalWide } from "../../ui/molecules/Modal";
import { OfferCheck, OfferCheckVariables } from "./__generated__/OfferCheck";
import { GetOffer_admin_Offer } from "./graphql/queries/__generated__/GetOffer";

type Props = {
  isOpen: boolean;
  offer: GetOffer_admin_Offer;
  handleCancel: () => void;
};

interface SubmitValue {
  usersToCheck: string[];
}

const OfferRentProfileModal = ({ isOpen, handleCancel, offer }: Props) => {
  const [addData] = useMutation<OfferCheck, OfferCheckVariables>(OFFER_CHECK);
  const handleSubmit = ({ usersToCheck }: SubmitValue) => {
    void addData({ variables: { id: offer.id, tenants: usersToCheck } });
    handleCancel();
  };

  return (
    <ModalWide
      isOpen={isOpen}
      onCancel={handleCancel}
      title="Who to check?"
      width={450}
    >
      <div>
        <Form onSubmit={handleSubmit}>
          {({ handleSubmit, values }) => (
            <FormSubmit onSubmit={handleSubmit}>
              <Group>
                {offer.tenants?.map((tenant, index) => (
                  <Fragment key={tenant?.email_primary ?? index}>
                    <Field
                      name="usersToCheck"
                      render={({ input }) => (
                        <Block>
                          <Checkbox input={input} />
                          <Text>
                            <b>Tenant:</b> {tenant.first_name}{" "}
                            {tenant.last_name}
                          </Text>
                        </Block>
                      )}
                      type="checkbox"
                      value={tenant.email_primary}
                    />
                  </Fragment>
                ))}
                {(offer.guarantors ?? []).map((g, idx) => (
                  <Fragment key={g.email_primary ?? idx}>
                    <Field
                      name="usersToCheck"
                      render={({ input }) => (
                        <Block>
                          <Checkbox input={input} />
                          <Text>
                            <b>Guarantor:</b> {g.first_name} {g.last_name}
                          </Text>
                        </Block>
                      )}
                      type="checkbox"
                      value={g.email_primary}
                    />
                  </Fragment>
                ))}
              </Group>
              <PrimaryButton
                disabled={
                  !values.usersToCheck || values.usersToCheck.length === 0
                }
                style={{ width: 200 }}
              >
                Submit
              </PrimaryButton>
            </FormSubmit>
          )}
        </Form>
      </div>
    </ModalWide>
  );
};

const Text = styled.span`
  margin-left: 20px;
`;

const FormSubmit = styled.form`
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
`;

const Block = styled.label`
  display: flex;
  margin: 20px;
`;

const Group = styled.div`
  display: flex;
  flex-direction: column;
  align-items: flex-start;
`;

const OFFER_CHECK = gql`
  mutation OfferCheck($id: String!, $tenants: [String!]) {
    admin {
      executeOfferCheck(id: $id, tenants: $tenants) {
        status
      }
    }
  }
`;

export default OfferRentProfileModal;
