import React, { FC, useCallback, useState } from "react";

import styled from "@emotion/styled";
import gql from "graphql-tag";
import { useMutation } from "react-apollo";

import { PrimaryButton } from "../../../../ui/atoms/Button";
import { ModalAlert, ModalConfirm } from "../../../../ui/molecules/Modal";
import {
  recreateDraftContract,
  recreateDraftContractVariables,
} from "./__generated__/recreateDraftContract";

type Props = {
  offerId: string;
};

const RecreateContract: FC<Props> = ({ offerId }) => {
  const [alert, setAlert] = useState<React.ReactNode>();
  const [showConfirm, setConfirm] = useState<boolean>(false);
  const [recreate] = useMutation<
    recreateDraftContract,
    recreateDraftContractVariables
  >(RECREATE_DRAFT_CONTRACT);

  const handleCancel = useCallback(() => {
    if (showConfirm) {
      setConfirm(false);
    }
  }, [showConfirm]);

  const handleConfirm = useCallback(() => {
    if (showConfirm) {
      setConfirm(false);
    }
    recreate({
      variables: {
        offer: offerId,
      },
    }).then((res) => {
      const isSuccess = res.data?.admin?.updateDraftContract?.success;
      const isError = res.data?.admin?.updateDraftContract?.errors;

      if (isSuccess) {
        setAlert("The draft contract has been recreated successfully!");
      } else if (isError != null) {
        setAlert(
          <>
            Can not recreate the draft contract, <br />
            {isError.join(", ")}
          </>
        );
      }
    });
  }, [offerId, recreate, showConfirm]);

  return (
    <Container>
      {alert && (
        <ModalAlert
          onCancel={() => {
            setAlert("");
          }}
        >
          <b>{alert}</b>
        </ModalAlert>
      )}
      {showConfirm && (
        <ModalConfirm onCancel={handleCancel} onConfirm={handleConfirm}>
          <span>
            Are you sure you really want to <br />
            <b>recreate the draft contract</b>?
          </span>
        </ModalConfirm>
      )}
      <PrimaryButton onClick={() => setConfirm(true)}>
        Recreate the draft contract
      </PrimaryButton>
    </Container>
  );
};

const Container = styled.div`
  float: right;
`;

const RECREATE_DRAFT_CONTRACT = gql`
  mutation recreateDraftContract($offer: String) {
    admin {
      updateDraftContract(offer: $offer) {
        errors
        offer {
          id
        }
        success
      }
    }
  }
`;

export default RecreateContract;
