// TODO: clean code this components
import React, { useMemo } from "react";

import styled from "@emotion/styled";
import { sentenceCase } from "change-case";
import { useMutation } from "react-apollo";
import { Field, Form } from "react-final-form";

import {
  extras_api_ServiceRoleEnum,
  extras_api_ServiceStatusEnum as ServiceStatusEnum,
  extras_api_ServiceTypeEnum,
  invoice_api_PaymentStatusEnum as PaymentStatusEnum,
  offer_api_OfferStateEnum,
} from "../../../../globalTypes";
import { PrimaryButton } from "../../../../ui/atoms/Button";
import {
  PropertyAside,
  PropertyVerifiedBlock,
} from "../../../../ui/atoms/Property";
import { UserFormRow } from "../../../../ui/atoms/UserForm";
import { CheckboxToggle } from "../../../../ui/molecules/CheckboxToggle";
import theme from "../../../../ui/theme";
import { formatDateWordTime } from "../../../../util/date";
import { formatPrice } from "../../../../util/price";
import {
  SkipHoldingDeposit,
  SkipHoldingDepositVariables,
} from "../../graphql/mutations/__generated__/SkipHoldingDeposit";
import {
  UpdatePayment,
  UpdatePaymentVariables,
} from "../../graphql/mutations/__generated__/UpdatePayment";
import SKIP_HOLDING_DEPOSIT from "../../graphql/mutations/SkipHoldingDeposit.graphql";
import UPDATE_PAYMENT_STATUS from "../../graphql/mutations/UpdatePayment.graphql";
import { GetOffer_admin_Offer } from "../../graphql/queries/__generated__/GetOffer";
import PaymentStatus from "../../PaymentStatus";
import Countdown from "./Countdown";

type Props = { offer: GetOffer_admin_Offer; refetchOffer: () => void };

const TabDeposit: React.FC<Props> = ({ offer, refetchOffer }) => {
  const [confirmPayment, { loading, error }] = useMutation<
    UpdatePayment,
    UpdatePaymentVariables
  >(UPDATE_PAYMENT_STATUS);

  const invoice = useMemo(
    () =>
      offer.invoices.find((p) =>
        (p.services ?? []).find(
          (s) =>
            s.service.type === extras_api_ServiceTypeEnum.DEPOSIT &&
            s.service.role === extras_api_ServiceRoleEnum.TENANT_DEPOSIT
        )
      ),
    [offer.invoices]
  );

  // TODO: clean if statement code => this is the bad way to return component (too much re-render)
  const isOnHoldingDeposit =
    offer.state === offer_api_OfferStateEnum.HOLDING_DEPOSIT;
  const [confirmSkipDeposit, { loading: isSkipLoading }] = useMutation<
    SkipHoldingDeposit,
    SkipHoldingDepositVariables
  >(SKIP_HOLDING_DEPOSIT);
  const handleSkipDeposit = async () => {
    const res = await confirmSkipDeposit({ variables: { offer_id: offer.id } });
    if (res.data?.admin?.skipHoldingDeposit?.success) {refetchOffer();}
  };

  if (isOnHoldingDeposit) {
    return (
      <PrimaryButton onClick={handleSkipDeposit}>
        {!isSkipLoading ? "Skip HD step" : "Loading..."}
      </PrimaryButton>
    );
  }

  if (!invoice || !invoice.services || !invoice.payments) {
    return null;
  }

  const service = invoice.services[0];

  const handleApproveSubmit = (payment_id: string) => {
    confirmPayment({
      variables: {
        payment_id,
        status: PaymentStatusEnum.PAYMENT_SUCCESS,
      },
    }).then(
      (res) => res.data?.admin?.updatePaymentStatus?.ok && refetchOffer()
    );
  };

  return (
    <>
      <ContentWrapper>
        <OfferInfo>
          <div>
            <b>OFFER ACCEPTED:</b>
            {formatDateWordTime(offer.accepted_at_value)}
          </div>
          {service.status !== ServiceStatusEnum.ACTIVE &&
            offer.accepted_at_value !== "" && (
              <div>
                <Countdown
                  msEnd={
                    new Date(offer.accepted_at_value).getTime() +
                    24 * 60 * 60 * 1000
                  }
                >
                  {({ ms, time, timeExpired }) =>
                    ms > 0 ? (
                      <>
                        <b>
                          <Alert>EXPIRES:</Alert>
                        </b>
                        {time}
                      </>
                    ) : (
                      <>
                        <b>
                          <Alert>EXPIRED:</Alert>
                        </b>
                        {timeExpired}
                      </>
                    )
                  }
                </Countdown>
              </div>
            )}
        </OfferInfo>

        <DepositInfo>
          <DepositInfoRow>
            <DepositInfoTitle>Invoice status</DepositInfoTitle>
            <div>{sentenceCase(invoice.status)}</div>
          </DepositInfoRow>
          <DepositInfoRow>
            <DepositInfoTitle>Invoice ID</DepositInfoTitle>
            <div>{invoice.invoice_id}</div>
          </DepositInfoRow>
          <DepositInfoRow>
            <DepositInfoTitle>Reference</DepositInfoTitle>
            <div>{invoice.reference}</div>
          </DepositInfoRow>
          <DepositInfoRow>
            <DepositInfoTitle>Created</DepositInfoTitle>
            <div>{formatDateWordTime(invoice.created_at)}</div>
          </DepositInfoRow>
          <DepositInfoRow>
            <DepositInfoTitle>Updated</DepositInfoTitle>
            <div>{formatDateWordTime(invoice.updated_at)}</div>
          </DepositInfoRow>
          <DepositInfoRow>
            <DepositInfoTitle>Amount</DepositInfoTitle>
            <div>{formatPrice(invoice.amount)}</div>
          </DepositInfoRow>
        </DepositInfo>
      </ContentWrapper>

      {invoice.payments.length === 0 ? (
        <h3>No payments have been made yet</h3>
      ) : (
        invoice.payments.map((payment) => {
          const isConfirmation =
            payment.status === PaymentStatusEnum.PAYMENT_CONFIRM;

          return (
            <>
              <h3>Payments</h3>
              <Wrapper key={payment.payment_id}>
                <ContentWrapper>
                  <DepositInfo>
                    <DepositInfoRow>
                      <DepositInfoTitle>Status</DepositInfoTitle>
                      <div>
                        <PaymentStatus status={payment.status} />
                      </div>
                    </DepositInfoRow>
                    <DepositInfoRow>
                      <DepositInfoTitle>Payment ID</DepositInfoTitle>
                      <div>{payment.payment_id}</div>
                    </DepositInfoRow>
                    <DepositInfoRow>
                      <DepositInfoTitle>Created</DepositInfoTitle>
                      <div>{formatDateWordTime(payment.created_at)}</div>
                    </DepositInfoRow>
                    <DepositInfoRow>
                      <DepositInfoTitle>Updated</DepositInfoTitle>
                      <div>{formatDateWordTime(payment.updated_at)}</div>
                    </DepositInfoRow>
                    <DepositInfoRow>
                      <DepositInfoTitle>Amount</DepositInfoTitle>
                      <div>{formatPrice(payment.amount)}</div>
                    </DepositInfoRow>
                  </DepositInfo>
                </ContentWrapper>

                <PropertyAside>
                  <PropertyVerifiedBlock>
                    <Form
                      initialValues={{
                        verified:
                          payment.status === PaymentStatusEnum.PAYMENT_SUCCESS,
                      }}
                      onSubmit={handleApproveSubmit}
                      render={({ handleSubmit }) => (
                        <form onSubmit={handleSubmit}>
                          <UserFormRow disabled={loading || !isConfirmation}>
                            <Field
                              component={CheckboxToggle}
                              disabled={loading || !isConfirmation}
                              labelText={"Confirmed"}
                              name={"verified"}
                              onChange={(event) =>
                                isConfirmation &&
                                event.target.checked &&
                                handleApproveSubmit(payment.payment_id)
                              }
                              type="checkbox"
                            />
                          </UserFormRow>

                          {error && <div>{error.message}</div>}
                        </form>
                      )}
                    />
                  </PropertyVerifiedBlock>
                </PropertyAside>
              </Wrapper>
            </>
          );
        })
      )}
    </>
  );
};

export default TabDeposit;

const Wrapper = styled.div`
  display: flex;
`;

const ContentWrapper = styled.div`
  width: calc(100% - 270px);
  padding: 20px 40px;
  background: white;
  border: solid 1px ${theme.colors.icons.darkBlue};
  border-radius: 5px;
  margin-bottom: 30px;
  font-size: 18px;
  line-height: 1.5;
  font-weight: 500;
`;

const OfferInfo = styled.div`
  display: flex;
  justify-content: space-between;
  padding-bottom: 15px;
  margin-bottom: 15px;
  border-bottom: 1px solid ${theme.colors.border.default};

  b {
    margin-right: 10px;
  }
`;

const Alert = styled.span`
  color: ${theme.colors.main.red};
`;

const DepositInfo = styled.div`
  padding-left: 80px;
`;

const DepositInfoRow = styled.div`
  display: flex;
  padding: 7px 0;
`;

const DepositInfoTitle = styled.div`
  width: 240px;
  text-transform: uppercase;
  font-weight: 700;
`;
