import React, { FC } from "react";

import styled from "@emotion/styled";

import { invoice_api_PaymentStatusEnum } from "../../../../../globalTypes";
import { formatDate, formatDateWordTime } from "../../../../../util/date";
import { formatPrice } from "../../../../../util/price";
import { GetOffer_admin_Offer_invoices_payments_matches } from "../../../graphql/queries/__generated__/GetOffer";
import PaymentReconciliationStatus from "../../../PaymentReconciliationStatus";
import PaymentStatus from "../../../PaymentStatus";

type Props = {
  amount: number;
  created_at: string;
  matches: readonly GetOffer_admin_Offer_invoices_payments_matches[] | null;
  payment_id: string;
  scheduled_at?: string;
  status: invoice_api_PaymentStatusEnum;
  updated_at: string;
};

const Payment: FC<Props> = ({
  amount,
  created_at,
  matches,
  payment_id,
  scheduled_at,
  status,
  updated_at,
}) => {
  return (
    <DepositInfo>
      <DepositInfoRow>
        <DepositInfoTitle>Status</DepositInfoTitle>
        <div>
          <PaymentStatus status={status} />
        </div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Reconciliation status</DepositInfoTitle>
        <div>
          <PaymentReconciliationStatus matches={matches} />
        </div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Payment ID</DepositInfoTitle>
        <div>{payment_id}</div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Created</DepositInfoTitle>
        <div>{formatDateWordTime(created_at)}</div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Updated</DepositInfoTitle>
        <div>{formatDateWordTime(updated_at)}</div>
      </DepositInfoRow>
      <DepositInfoRow>
        <DepositInfoTitle>Amount</DepositInfoTitle>
        <div>{formatPrice(amount)}</div>
      </DepositInfoRow>
      {scheduled_at ? (
        <DepositInfoRow>
          <DepositInfoTitle>Schedule payment time</DepositInfoTitle>
          <b>{formatDate(scheduled_at)}</b>
        </DepositInfoRow>
      ) : null}
    </DepositInfo>
  );
};

const DepositInfo = styled.div`
  padding-left: 0px;
`;
const DepositInfoRow = styled.div`
  display: flex;
  padding: 4px 10px;
  border-bottom: dashed 1px #eee;
  background: #ffffff99;

  &:last-child {
    border-bottom: 0;
  }
`;
const DepositInfoTitle = styled.div`
  width: 240px;
  text-transform: uppercase;
  font-weight: 700;
  font-size: 13px;
`;

export default Payment;
