import React, { FC, useState } from "react";

import { useQuery } from "react-apollo";

import { common_api_generic_query_QueryFilterOperatorEnum } from "../../../../globalTypes";
import Spinner from "../../../../ui/atoms/Spinner";
import SystemError from "../../../../ui/atoms/SystemError";
import { Table, Tbody, Thead } from "../../../../ui/atoms/Table";
import TableWrapper from "../../../../ui/atoms/TableWrapper";
import Pagebar from "../../../../ui/molecules/Pagebar";
import { GetOffer_admin_Offer as Offer } from "../../graphql/queries/__generated__/GetOffer";
import {
  OffersList,
  OffersListVariables,
} from "../../graphql/queries/__generated__/OffersList";
import OFFERS_LIST from "../../graphql/queries/GetListOfOffers.graphql";
import TabOfferHead from "./TabOfferHead";
import TabOfferItem from "./TabOfferItem";

type Props = { offer: Offer };

const TabOffer: FC<Props> = ({ offer }) => {
  const perPage = 10;
  const [page, setPage] = useState(1);
  const propertyId = offer?.property?.id;
  const { data, loading, error } = useQuery<OffersList, OffersListVariables>(
    OFFERS_LIST,
    {
      variables: {
        filter: [
          {
            operator: common_api_generic_query_QueryFilterOperatorEnum.EQUALS,
            fields: ["property"],
            value: [propertyId],
          },
        ],
        pagination: {
          page,
          perPage,
        },
      },
    }
  );

  if (loading) {
    return <Spinner />;
  }
  if (error) {
    return <SystemError error={error} />;
  }
  const totalOffers = data?.admin?.allOffers?.total ?? 0;
  const list = data?.admin?.allOffers?.data ?? [];

  return (
    <TableWrapper>
      <Table>
        <Thead>
          <TabOfferHead />
        </Thead>
        <Tbody>
          {list.map((v) => (
            <TabOfferItem key={v.id} offer={v} property={v.property} />
          ))}
        </Tbody>
      </Table>
      <Pagebar
        changePage={setPage}
        curPage={page}
        showNPages={3}
        total={Math.ceil(totalOffers / perPage)}
      />
    </TableWrapper>
  );
};

export default TabOffer;
