import React, { useState } from "react";

import format from "date-fns/format";
import { Link } from "react-router-dom";

import EmailLink from "../../../../ui/atoms/EmailLink";
import { TextButton } from "../../../../ui/atoms/Offer";
import { NoWrap, Td, Tr } from "../../../../ui/atoms/Table";
import { formatPrice } from "../../../../util/price";
import {
  OffersList_admin_allOffers_data as Offer,
  OffersList_admin_allOffers_data_property as Property,
} from "../../graphql/queries/__generated__/OffersList";
import OfferDetailsModal from "../../OfferDetailsModal";

type Props = {
  offer: Offer;
  property: Property | null;
};

const TabOfferItem: React.FC<Props> = ({ offer, property }) => {
  const {
    created_at_value,
    accepted_at_value,
    denied_at_value,
    cancelled_at_value,
    conditions,
    tenants,
  } = offer;
  const [showModal, setShowModal] = useState<boolean>(false);
  const offerProperty = offer!.property;

  if (!offerProperty) {
    return null;
  }

  const { rental } = offerProperty;

  const landlord = property?.people?.landlord;

  const leadingTenant = tenants && tenants.length > 0 ? tenants[0] : undefined;

  if (leadingTenant == null) {
    return null;
  }

  return (
    <>
      <Tr>
        <Td>
          <b>
            <Link className="link" to={`/users/${leadingTenant.user}/view`}>
              {leadingTenant.first_name}
              &nbsp;
              {leadingTenant.last_name}
            </Link>
          </b>
          {leadingTenant.email_primary && (
            <NoWrap title={leadingTenant.email_primary}>
              <EmailLink href={`mailto:${leadingTenant.email_primary}`}>
                {leadingTenant.email_primary}
              </EmailLink>
            </NoWrap>
          )}
        </Td>
        <Td>{format(new Date(created_at_value), "dd MMM yyyy HH:mm:ss")}</Td>
        <Td>
          {accepted_at_value !== "" && (
            <Link className="link" to={`/users/${landlord!.id}/view`}>
              {landlord?.details?.first_name}
              &nbsp;
              {landlord?.details?.last_name}
            </Link>
          )}
        </Td>
        <Td>
          {accepted_at_value !== "" &&
            format(new Date(accepted_at_value), "dd MMM yyyy HH:mm:ss")}
        </Td>
        <Td>
          {denied_at_value !== "" && (
            <Link className="link" to={`/users/${landlord!.id}/view`}>
              {landlord?.details?.first_name}
              &nbsp;
              {landlord?.details?.last_name}
            </Link>
          )}
          {cancelled_at_value !== "" && (
            <Link className="link" to={`/users/${leadingTenant.user}/view`}>
              {leadingTenant.first_name}
              &nbsp;
              {leadingTenant.last_name}
            </Link>
          )}
        </Td>
        <Td>
          {denied_at_value !== "" &&
            format(new Date(denied_at_value), "dd MMM yyyy HH:mm:ss")}
          {cancelled_at_value !== "" &&
            format(new Date(cancelled_at_value), "dd MMM yyyy HH:mm:ss")}
        </Td>
        <Td>
          <b>{formatPrice(conditions.price, 0)}</b>
        </Td>
        <Td>
          <b>{formatPrice(rental.rental_price, 0)}</b>
        </Td>
        <Td>
          <TextButton
            onClick={() => setShowModal(true)}
            onKeyDown={() => setShowModal(true)}
            role="button"
            tabIndex={0}
          >
            View details
          </TextButton>
        </Td>
      </Tr>

      {showModal && (
        <OfferDetailsModal
          offer={offer}
          onCancel={() => setShowModal(false)}
          property={property}
        />
      )}
    </>
  );
};
export default TabOfferItem;
