import React from "react";

import EmailLink from "../../../../ui/atoms/EmailLink";
import { StatusBlock, StatusListed } from "../../../../ui/atoms/Status";
import { Td, Tr } from "../../../../ui/atoms/Table";
import { EMPLOYMENT_STATUS } from "../../constants";
import { GetOffer_admin_Offer_tenants as Tenant } from "../../graphql/queries/__generated__/GetOffer";
import TenantRiskLink from "./TenantRiskLink";
import TenantRiskStatus from "./TenantRiskStatus";

type Props = { tenant: Tenant; idx: number };

const TabRentprofileTenantItem: React.FC<Props> = ({ tenant, idx }) => (
  <>
    <Tr>
      <Td>
        <b>
          {tenant.first_name}
          &nbsp;
          {tenant.last_name}
        </b>
        {tenant.email_primary && (
          <>
            <br />
            <EmailLink href={`mailto:${tenant.email_primary}`}>
              {tenant.email_primary}
            </EmailLink>
          </>
        )}
        {tenant.phone_primary && (
          <>
            <br />
            {tenant.phone_primary}
          </>
        )}
      </Td>
      <Td>
        <b>{idx === 0 ? "Leading tenant" : `Tenant # ${idx + 1}`}</b>
      </Td>
      <Td>{tenant.age}</Td>
      <Td>
        <b>{EMPLOYMENT_STATUS[tenant.employment_status]}</b>
      </Td>
      <Td>
        <b>
          {tenant.rentprofile_status ? (
            <StatusListed>{tenant.rentprofile_status}</StatusListed>
          ) : (
            <StatusBlock>Not found</StatusBlock>
          )}
        </b>
        <br />
        <b>Last dispatch date: {tenant.rentprofile_created_at || "unknown"}</b>
      </Td>
      <Td>
        <TenantRiskStatus status={tenant.risk} />
      </Td>
      <Td>
        <TenantRiskLink document={tenant!.risk_document as string} />
      </Td>
    </Tr>
  </>
);

export default TabRentprofileTenantItem;
