import React, { useMemo } from "react";

import { differenceInCalendarDays } from "date-fns";
import { Link } from "react-router-dom";

import { Td, Tr } from "../../ui/atoms/Table";
import { getPersonFullName } from "../../util";
import { formatDateTime } from "../../util/date";
import { getEditPropertyUrl } from "../../util/urls";
import {
  PayoutsGetAllPayments_admin_allPayments_payments_property_people_landlord_details,
  PayoutsGetAllPayments_admin_allPayments_payments_property_people_tenants_user_details,
} from "../payouts-made/graphql/queries/__generated__/PayoutsGetAllPayments";

export type ListItemProps = {
  address: string | null | undefined;
  amount: number | undefined;
  ivr: string;
  landlord_details:
    | PayoutsGetAllPayments_admin_allPayments_payments_property_people_landlord_details
    | null
    | undefined;
  overdue_payment_notice_count: number | null;
  payment_id: string;
  propertyId?: string;
  scheduled_at: string;
  tenantDetails?: PayoutsGetAllPayments_admin_allPayments_payments_property_people_tenants_user_details | null;
};

const ListItem: React.FC<ListItemProps> = ({
  address,
  amount,
  ivr,
  landlord_details,
  overdue_payment_notice_count,
  payment_id,
  propertyId,
  scheduled_at,
  tenantDetails,
}) => {
  const daysOverdue = differenceInCalendarDays(
    new Date(),
    new Date(scheduled_at)
  );

  // const [
  //   updatePayment,
  //    { loading: updatePaymentLoading }
  // ] = useMutation<UpdatePaymentStatus, UpdatePaymentStatusVariables>(
  //   UPDATE_PAYMENT_STATUS
  // );

  // const handleUpdateStatus = async (payment_id: string) => {
  //   await updatePayment({
  //     variables: {
  //       payment_id,
  //       status: invoice_api_PaymentStatusEnum.PAYMENT_SUCCESS,
  //     },
  //     refetchQueries: ["PayoutsGetAllPayments"],
  //   });
  // };

  const landlordFullName = useMemo(
    () =>
      getPersonFullName({
        firstName: landlord_details?.first_name,
        lastName: landlord_details?.last_name,
      }),
    [landlord_details]
  );
  const tenantFullName = useMemo(
    () =>
      getPersonFullName({
        firstName: tenantDetails?.first_name,
        lastName: tenantDetails?.last_name,
      }),
    [tenantDetails]
  );

  return (
    <Tr>
      <Td>
        <Link className="link" to={getEditPropertyUrl(propertyId)}>
          {address}
        </Link>
      </Td>
      <Td>{landlordFullName}</Td>
      <Td>{tenantFullName}</Td>
      <Td>{ivr}</Td>
      <Td>{formatDateTime(scheduled_at)}</Td>
      <Td>{daysOverdue}</Td>
      <Td>{amount}</Td>
      <Td>{overdue_payment_notice_count}</Td>
      {/* <Td colSpan={2}>
        <ButtonMark
          onClick={() => {
            handleUpdateStatus(payment_id);
          }}
          type="button"
        >
          {updatePaymentLoading ? "loading" : "Mark as paid"}
        </ButtonMark>
      </Td> */}
    </Tr>
  );
};

// const ButtonMark = styled(PrimaryButton)`
//   width: 100%;
// `;

export default ListItem;
