import React from "react";

import AntdButton from "antd-button-color";
import { sentenceCase } from "change-case";
import { useMutation } from "react-apollo";
import { Link } from "react-router-dom";

import { Table, Tbody, Td, Th, Thead, Tr } from "../../../../../ui/atoms/Table";
import {
  AddPaymentTransactionMatch,
  AddPaymentTransactionMatchVariables,
} from "../../../graphql/mutations/__generated__/AddPaymentTransactionMatch";
import ADD_TRANSACTION_MATCH from "../../../graphql/mutations/AddPaymentTransactionMatch.graphql";
import { MatchesProps } from "./types";

export const Matches = ({
  matches,
  transactionId,
  isFullyMatched,
  amount,
}: MatchesProps) => {
  const admin_id = window.localStorage.getItem("adminId") ?? "";

  const [createPayment, { loading: createPaymentLoading }] = useMutation<
    AddPaymentTransactionMatch,
    AddPaymentTransactionMatchVariables
  >(ADD_TRANSACTION_MATCH);

  return (
    <Table>
      <Thead>
        <Tr>
          <Th>Invoice ID</Th>
          <Th>Property</Th>
          <Th>Payment</Th>
          <Th>Match</Th>
          <Th>Matched</Th>
        </Tr>
      </Thead>
      <Tbody>
        {matches?.map((match) => {
          const { payment, matched } = match;
          const { property, invoice_id, invoice } = payment ?? {};

          const handleUpdateStatus = async (transaction_id: string) => {
            await createPayment({
              variables: {
                transaction_id,
                comment: "custom matching",
                admin_id,
                find: { invoice_id },
              },
            });
            window.location.reload();
          };

          return (
            <Tr key={match.payment_id}>
              <Td>
                <Link
                  className="link"
                  to={{
                    pathname: "/invoices/details",
                    search: `invoiceId=${invoice_id}`,
                  }}
                >
                  {invoice_id}
                </Link>
              </Td>
              <Td>
                Address: {property?.location.address}
                <br />
                Landlord: {property?.people.landlord?.details?.full_name}
              </Td>
              <Td>
                Correlation target: {invoice?.correlation_target}
                <br />
                Amount: {amount}
              </Td>
              <Td>
                {!isFullyMatched && (
                  <AntdButton
                    block
                    htmlType="button"
                    onClick={() => handleUpdateStatus(transactionId)}
                    type="primary"
                  >
                    {createPaymentLoading ? "loading" : "Match"}
                  </AntdButton>
                )}
              </Td>
              <Td>
                {matched
                  ?.map((m) =>
                    sentenceCase(m.replace("TRANSACTION_MATCH_", ""))
                  )
                  .join(", ")}
              </Td>
            </Tr>
          );
        })}
      </Tbody>
    </Table>
  );
};
