import React from "react";

import { Query } from "react-apollo";
import { Link } from "react-router-dom";
import { oc } from "ts-optchain";

import SystemError from "../../ui/atoms/SystemError";
import {
  PaymentsGetAdmin,
  PaymentsGetAdminVariables,
} from "./graphql/queries/__generated__/PaymentsGetAdmin";
import GET_ADMIN from "./graphql/queries/PaymentsGetAdmin.graphql";

const UserInfo = ({ adminId }: { adminId: string }) => (
  <Query<PaymentsGetAdmin, PaymentsGetAdminVariables>
    query={GET_ADMIN}
    variables={{ id: adminId }}
  >
    {({ data, loading, error }) => {
      if (error) {
        return <SystemError error={error} />;
      } else if (loading) {
        return <>loading...</>;
      }

      const admin = oc(data).admin.Admin();

      if (!admin) {
        return null;
      }

      return (
        <Link className="link" to={`/admin/${admin.id}/edit`}>
          {admin!.details!.first_name}&nbsp;{admin!.details!.last_name}
        </Link>
      );
    }}
  </Query>
);

export default UserInfo;
