import React, { FC } from "react";

import DocumentIcon from "./DocumentIcon";
import { DocumentViewerProps } from "./types";

import styles from "./styles.module.css";

const DocumentViewer: FC<DocumentViewerProps> = ({ invoice }) => {
  const products = invoice.order?.products ?? [];
  const productsWithDocuments = products.length
    ? products.filter((product) => product.documents?.length)
    : null;

  if (!productsWithDocuments?.length) {
    return null;
  }

  return (
    <div className={styles.documents}>
      <div className={styles.title}>Documents</div>
      {productsWithDocuments.map((productWithDocuments) => (
        <div key={productWithDocuments.id} className={styles.list}>
          {productWithDocuments.documents?.map((document) => (
            <a
              key={document?.file?.id}
              className={styles.item}
              href={`/media/${document?.file?.id}`}
              target="blank"
            >
              <DocumentIcon className={styles.icon} />
              <div className={styles.name}>{document?.file?.name}</div>
            </a>
          ))}
        </div>
      ))}
    </div>
  );
};

export default DocumentViewer;
