import React, { FC, useMemo } from "react";

import { Link } from "react-router-dom";

import { NoWrap, Td, Tr } from "../../../ui/atoms/Table";
import Checkbox from "../../../ui/molecules/Checkbox";
import { formatDateTime } from "../../../util/date";
import { formatPrice } from "../../../util/price";
import { propertyAddressFilter } from "../../listing/filters";
import { PaymentsGetAllInvoices_admin_allInvoices_invoices as Invoice } from "../graphql/queries/__generated__/PaymentsGetAllInvoices";
import { getInvoiceStatus, getInvoiceType } from "./utils";

export type ListItemProps = {
  invoice: Invoice;
  selectRow(id: string): void;
  selectedRows: string[];
};

const ListItem: FC<ListItemProps> = ({ invoice, selectRow, selectedRows }) => {
  const products = useMemo(() => invoice.order?.products ?? [], [
    invoice.order,
  ]);

  const services = useMemo(
    () => invoice.services?.map((s) => s.service.title).join(", "),
    [invoice]
  );

  return (
    <Tr
      className={
        selectedRows.includes(invoice.invoice_id) ? "selected-row" : ""
      }
    >
      <Td>
        <Checkbox
          input={{
            onChange: selectRow(invoice.invoice_id),
          }}
        />
      </Td>
      <Td>{invoice.invoice_id}</Td>
      <Td>
        <NoWrap>{invoice.reference}</NoWrap>
      </Td>
      <Td>{formatDateTime(invoice.created_at)}</Td>
      <Td>{formatDateTime(invoice.updated_at)}</Td>
      <Td>
        {products.length > 0 ? (
          <>
            {propertyAddressFilter(products[0].details.property.location)}
            <br />
            {products[0].details.property.id && (
              <Link
                className="link"
                to={`/listing/${products[0].details.property.id}/edit`}
              >
                ...{products[0].details.property.id?.substr(-12)}
              </Link>
            )}
          </>
        ) : (
          "—"
        )}
      </Td>
      <Td>
        {invoice.order?.userid ? (
          <Link className="link" to={`/users/${invoice.order.userid}/view`}>
            {invoice.order.userdata.details.first_name}&nbsp;
            {invoice.order.userdata.details.last_name}
          </Link>
        ) : (
          "—"
        )}
      </Td>
      <Td>{getInvoiceType(invoice.type)}</Td>
      <Td>{services}</Td>
      <Td>
        <b>{formatPrice(invoice.amount)}</b>
      </Td>
      <Td>{invoice.xero_code ?? "-"}</Td>
      <Td>{getInvoiceStatus(invoice.status)}</Td>
      <Td>
        <Link
          className="link"
          to={{
            pathname: "/invoices/details",
            search: `invoiceId=${invoice.invoice_id}`,
          }}
        >
          View
        </Link>
      </Td>
    </Tr>
  );
};

export default ListItem;
