import React from "react";

import { sentenceCase } from "change-case";
import { Link } from "react-router-dom";

import { invoice_api_PaymentStatusEnum } from "../../globalTypes";
import { NoWrap, Td, Tr } from "../../ui/atoms/Table";
import { formatDateTime } from "../../util/date";
import { formatPrice } from "../../util/price";
import { PaymentsGetAllPayments_admin_allPayments_payments as Payment } from "./graphql/queries/__generated__/PaymentsGetAllPayments";
import PropertyInfo from "./PropertyInfo";
import UserInfo from "./UserInfo";

const getPaymentStatus = (status: invoice_api_PaymentStatusEnum) => {
  switch (status) {
    case invoice_api_PaymentStatusEnum.PAYMENT_CANCELED:
      return "Canceled";
    case invoice_api_PaymentStatusEnum.PAYMENT_CONFIRM:
      return "Confirm";
    case invoice_api_PaymentStatusEnum.PAYMENT_FAILED:
      return "Failed";
    case invoice_api_PaymentStatusEnum.PAYMENT_PENDING:
      return "Pending";
    case invoice_api_PaymentStatusEnum.PAYMENT_SUCCESS:
      return "Success";
    default:
      return sentenceCase(status);
  }
};

export type ListItemProps = {
  payment: Payment;
};

const ListItem: React.FC<ListItemProps> = ({ payment }) => (
  <Tr>
    <Td>{payment.payment_id}</Td>
    <Td>
      <Link
        className="link"
        to={{
          pathname: "/invoices/details",
          search: `invoiceId=${payment.invoice_id}`,
        }}
      >
        {payment.invoice_id}
      </Link>
    </Td>
    <Td>
      <NoWrap>{payment.reference}</NoWrap>
    </Td>
    <Td>{formatDateTime(payment.created_at)}</Td>
    <Td>{formatDateTime(payment.updated_at)}</Td>
    <Td>
      {payment.property?.id != null ? (
        <PropertyInfo propertyId={payment.property?.id} />
      ) : (
        "No associated property"
      )}
    </Td>
    <Td>
      <UserInfo userId={payment.user} />
    </Td>
    <Td>
      <b>{formatPrice(payment.amount)}</b>
    </Td>
    <Td>{getPaymentStatus(payment.status)}</Td>
  </Tr>
);

export default ListItem;
