import React from "react";

import { Query } from "react-apollo";
import { Link } from "react-router-dom";

import { propertyAddressFilter } from "../listing/filters";
import {
  PaymentsGetPropertyLocation,
  PaymentsGetPropertyLocationVariables,
} from "./graphql/queries/__generated__/PaymentsGetPropertyLocation";
import GET_PROPERTY from "./graphql/queries/PaymentsGetPropertyLocation.graphql";

const PropertyInfo = ({ propertyId }: { propertyId: string }) => (
  <Query<PaymentsGetPropertyLocation, PaymentsGetPropertyLocationVariables>
    query={GET_PROPERTY}
    variables={{ id: propertyId }}
  >
    {({ data, loading, error }) => {
      if (error) {
        return <>Error... See console</>;
      } else if (loading) {
        return <>loading...</>;
      }

      const property = data?.admin?.Property;

      if (!property) {
        return null;
      }

      return (
        <>
          {propertyAddressFilter(property.location)}
          <br />
          <Link className="link" to={`/listing/${property.id}/edit`}>
            ...{(property!.id as string).substr(-12)}
          </Link>
        </>
      );
    }}
  </Query>
);

export default PropertyInfo;
