import React, { FC, useEffect, useState } from "react";

import { CopyToClipboard } from "react-copy-to-clipboard";

import { SecondaryButton } from "../../../ui/atoms/Button";

type Props = {
  textForCopy: string;
};

const TIMEOUT = 2000;

const CopyButton: FC<Props> = ({ children, textForCopy }) => {
  const [copied, setCopied] = useState(false);

  useEffect(() => {
    let timer;

    if (copied) {
      timer = setTimeout(() => {
        setCopied(false);
      }, TIMEOUT);
    }

    return () => {
      if (timer) {
        clearTimeout(timer);
        timer = null;
      }
    };
  }, [copied]);

  return (
    <CopyToClipboard onCopy={() => setCopied(true)} text={textForCopy}>
      <SecondaryButton type="button">
        {copied ? "Copied!" : children}
      </SecondaryButton>
    </CopyToClipboard>
  );
};

export default CopyButton;
