import React, { FC } from "react";

import { Link } from "react-router-dom";

import { PropertyCardItemTitle } from "../../../../ui/atoms/Property";
import { PaymentsGetProperty_admin_Property_people_landlord } from "../../graphql/queries/__generated__/PaymentsGetProperty";

import css from "./index.module.css";

type Props = {
  landlord: PaymentsGetProperty_admin_Property_people_landlord | null;
};

const LandlordInfo: FC<Props> = ({ landlord }) => {
  if (!landlord) {
    return null;
  }

  const { details, contact } = landlord;

  return (
    <div className={css.container}>
      <PropertyCardItemTitle>Landlord</PropertyCardItemTitle>
      <Link
        className={css.linkIcon}
        target="_blank"
        to={`/users/${landlord.id}/view`}
      >
        <i className="material-icons">open_in_new</i>
      </Link>
      {details?.avatar?.id ? (
        <img
          alt={details.first_name ?? ""}
          className={css.avatar}
          src={`/media/thumb-${details.avatar.id}`}
        />
      ) : (
        <div className={css.avatarPlaceholder}>
          {details?.first_name?.slice(0, 1)} {details?.last_name?.slice(0, 1)}
        </div>
      )}
      <div className={css.name}>
        {details?.first_name} {details?.last_name}
      </div>
      <div className={css.text}>
        <a href={`mailto:${contact?.email_primary}`}>
          {contact?.email_primary}
        </a>
      </div>
      <div className={css.text}>
        <a href={`tel:${contact?.phone_primary}`}>{contact?.phone_primary}</a>
      </div>
    </div>
  );
};

export default LandlordInfo;
