import React, { FC } from "react";

import {
  ColumnTitle,
  ColumnValue,
  PaymentRow,
} from "../../../../ui/atoms/Payment";
import { formatDateTime } from "../../../../util/date";
import { formatOrdinal } from "../../../../util/ordinal";
import { formatPrice } from "../../../../util/price";
import { ScheduledPaymentOutputFields_parts_invoice } from "../../graphql/fragments/__generated__/ScheduledPaymentOutputFields";
import { PaymentsGetAllScheduledPayments_admin_allScheduledPayments_data_parts_payment as AllScheduledPayments_data_parts_payment } from "../../graphql/queries/__generated__/PaymentsGetAllScheduledPayments";
import {
  PaymentsGetOfferForTenancy_admin_Offer,
  PaymentsGetOfferForTenancy_admin_Offer_invoices,
} from "../../graphql/queries/__generated__/PaymentsGetOfferForTenancy";

import css from "./index.module.css";

type Props = {
  payment: AllScheduledPayments_data_parts_payment | null | undefined;
  offer: PaymentsGetOfferForTenancy_admin_Offer;
  isDRP: boolean;
  paymentIdx: number;
  standingOrderInvoice:
    | Pick<ScheduledPaymentOutputFields_parts_invoice, "setup">
    | null
    | undefined;
  holdingDepositInvoice?:
    | PaymentsGetOfferForTenancy_admin_Offer_invoices
    | undefined;
  depositPrice?: number | null | undefined;
};

const Payment: FC<Props> = ({
  payment,
  offer,
  isDRP,
  paymentIdx,
  standingOrderInvoice,
  holdingDepositInvoice,
  depositPrice,
}) => {
  const leadTenant = offer.tenants?.[0];

  return (
    <>
      <h3 className={css.subTitle}>
        Payment
        {payment && (
          <>
            &nbsp;&nbsp;
            <span>
              Due:&nbsp;
              {formatDateTime(payment.scheduled_at)}
            </span>
          </>
        )}
      </h3>
      <div className={css.blockContainer}>
        {paymentIdx === 1 ? (
          <div className={css.blockText}>
            The agreed rent is <b>{formatPrice(offer.conditions.price)}</b> per
            month and the tenants are paying in monthly instalments, so the
            first instalment is equal to one month of rent minus the holding
            deposit of <b>{formatPrice(holdingDepositInvoice?.amount)}</b>.{" "}
            {isDRP ? (
              <>
                The deposit replacement is <b>{formatPrice(depositPrice)}</b>
              </>
            ) : (
              <>
                The traditional deposit of 5 weeks' of rent is also due at this
                stage <b>{formatPrice(depositPrice)}</b>
              </>
            )}
          </div>
        ) : (
          <div className={css.blockText}>
            The agreed rent is <b>{formatPrice(offer.conditions.price)}</b> per
            month and the tenants are paying in monthly instalments, so the{" "}
            {formatOrdinal(paymentIdx)} instalment is equal to one month of
            rent: <b>{formatPrice(offer.conditions.price)}</b>
          </div>
        )}
        <PaymentRow>
          <div className={css.column33}>
            <ColumnTitle>Amount due</ColumnTitle>
            <ColumnValue>{formatPrice(payment?.amount)}</ColumnValue>
          </div>
          <div className={css.column33}>
            <ColumnTitle>Payer</ColumnTitle>
            <ColumnValue>
              {leadTenant?.first_name} {leadTenant?.last_name}
            </ColumnValue>
          </div>
          <div className={css.column33}>
            <ColumnTitle>Standing order</ColumnTitle>
            <ColumnValue>
              {standingOrderInvoice == null
                ? "—"
                : standingOrderInvoice.setup
                ? "Setup with Token"
                : "Not setup with Token"}
            </ColumnValue>
          </div>
        </PaymentRow>
      </div>
    </>
  );
};

export default Payment;
