import React, { FC, useMemo } from "react";

import { format } from "date-fns";

import { offer_api_DepositTypeEnum } from "../../../../globalTypes";
import {
  PaymentBody,
  PaymentClose,
  PaymentConfirmed,
  PaymentDescription,
  PaymentHead,
  PaymentOpen,
} from "../../../../ui/atoms/Payment";
import Collapse from "../../../../ui/molecules/Collapse";
import { PaymentsGetAllScheduledPayments_admin_allScheduledPayments_data as AllScheduledPayments } from "../../graphql/queries/__generated__/PaymentsGetAllScheduledPayments";
import { PaymentsGetOfferForTenancy_admin_Offer } from "../../graphql/queries/__generated__/PaymentsGetOfferForTenancy";
import { PaymentsGetProperty_admin_Property } from "../../graphql/queries/__generated__/PaymentsGetProperty";
import Payment from "./Payment";
import Payout from "./Payout";
import Reconciliation from "./Reconciliation";

import css from "./index.module.css";

type Props = {
  scheduledItem: AllScheduledPayments;
  offer: PaymentsGetOfferForTenancy_admin_Offer;
  property: PaymentsGetProperty_admin_Property;
  paymentIdx: number;
  total: number;
};

const RentPayment: FC<Props> = ({
  scheduledItem,
  offer,
  property,
  paymentIdx,
  total,
}) => {
  const payment = useMemo(
    () =>
      scheduledItem?.parts?.find(
        (p) => p.payment?.correlation_target === "standing-order"
      )?.payment,
    [scheduledItem]
  );

  const payout = useMemo(() => scheduledItem.payout.invoice?.payments?.[0], [
    scheduledItem,
  ]);

  const invoice = useMemo(
    () =>
      scheduledItem.parts?.find(
        (p) => p.invoice?.correlation_target === "standing-order"
      )?.invoice,
    [scheduledItem]
  );

  const isDRP =
    offer.conditions.deposit_type ===
    offer_api_DepositTypeEnum.DEPOSIT_REPLACEMENT;

  return (
    <Collapse opened={false}>
      {({ toggle, isOpened }) => (
        <PaymentConfirmed>
          <PaymentHead>
            {isOpened ? (
              <PaymentClose onClick={toggle} />
            ) : (
              <PaymentOpen onClick={toggle} />
            )}
            <PaymentDescription>
              <b>
                Rent Payment -{" "}
                {format(
                  new Date(
                    scheduledItem.date.year,
                    scheduledItem.date.month - 1
                  ),
                  "MMMM"
                )}{" "}
                ({paymentIdx} of {total})
              </b>
            </PaymentDescription>
          </PaymentHead>

          {isOpened && payment && (
            <PaymentBody className={css.pageContent}>
              <Payment
                isDRP={isDRP}
                offer={offer}
                payment={payment}
                paymentIdx={paymentIdx}
                standingOrderInvoice={invoice}
              />

              <Reconciliation ivr={property.ivr} payment={payment} />

              <Payout
                ivr={property.ivr}
                offer={offer}
                payment={payout}
                scheduledPayment={scheduledItem}
              />
            </PaymentBody>
          )}
        </PaymentConfirmed>
      )}
    </Collapse>
  );
};

export default RentPayment;
