import React, { FC, useMemo } from "react";

import { PaymentsGetAllScheduledPayments_admin_allScheduledPayments_data as AllScheduledPayments } from "../../graphql/queries/__generated__/PaymentsGetAllScheduledPayments";
import { PaymentsGetOfferForTenancy_admin_Offer } from "../../graphql/queries/__generated__/PaymentsGetOfferForTenancy";
import { PaymentsGetProperty_admin_Property } from "../../graphql/queries/__generated__/PaymentsGetProperty";
import MoveinPayments from "./MoveinPayments";
import RentPayment from "./RentPayment";

type Props = {
  scheduledPayments: readonly AllScheduledPayments[];
  offer: PaymentsGetOfferForTenancy_admin_Offer;
  property: PaymentsGetProperty_admin_Property;
};

const Payments: FC<Props> = ({ scheduledPayments, offer, property }) => {
  const tenantServicesScheduled = useMemo(
    () =>
      scheduledPayments.find((s) =>
        s.parts?.some(
          (p) => p.payment?.correlation_target === "tenant-services"
        )
      ),
    [scheduledPayments]
  );
  const tenantServicesPayment = useMemo(
    () =>
      tenantServicesScheduled?.parts?.find(
        (p) => p.payment?.correlation_target === "tenant-services"
      )?.payment,
    [tenantServicesScheduled]
  );
  const standingOrderScheduledItems = useMemo(
    () =>
      scheduledPayments
        .filter((s) =>
          s.parts?.some(
            (p) => p.payment?.correlation_target === "standing-order"
          )
        )
        .reverse(),
    [scheduledPayments]
  );

  return (
    <>
      <MoveinPayments
        offer={offer}
        payment={tenantServicesPayment}
        property={property}
        scheduledItem={tenantServicesScheduled}
      />

      {standingOrderScheduledItems.map((p, idx) => (
        <RentPayment
          key={p.id}
          offer={offer}
          paymentIdx={idx + 2}
          property={property}
          scheduledItem={p}
          total={standingOrderScheduledItems.length + 1}
        />
      ))}
    </>
  );
};

export default Payments;
