import React, { FC, useCallback } from "react";

import AntdButton from "antd-button-color";
import { addDays } from "date-fns";
import { useMutation } from "react-apollo";
import { Link } from "react-router-dom";

import { invoice_api_PaymentStatusEnum } from "../../globalTypes";
import { Td, Tr } from "../../ui/atoms/Table";
import { formatDateTime } from "../../util/date";
import {
  CreatePayment,
  CreatePaymentVariables,
} from "../payments/graphql/mutations/__generated__/CreatePayment";
import CREATE_PAYMENT from "../payments/graphql/mutations/CreatePayment.graphql";
import {
  PayoutsInvoicesOutputFields_property_data_bank_details,
  PayoutsInvoicesOutputFields_property_data_people_landlord_details,
} from "./graphql/fragments/__generated__/PayoutsInvoicesOutputFields";
import { PayoutsGetAllInvoices_admin_allInvoices_invoices_property_data_people_tenants_user_details } from "./graphql/queries/__generated__/PayoutsGetAllInvoices";

export type ListItemProps = {
  address: string | null | undefined;
  amount: number | undefined;
  created_at: string;
  landlord_details:
    | PayoutsInvoicesOutputFields_property_data_people_landlord_details
    | null
    | undefined;
  bank_details:
    | PayoutsInvoicesOutputFields_property_data_bank_details
    | null
    | undefined;
  invoice_id: string;
  ivr: string;
  tenantDetails:
    | PayoutsGetAllInvoices_admin_allInvoices_invoices_property_data_people_tenants_user_details
    | null
    | undefined;
  updated_at: string;
  type: string;
  propertyId: string | undefined;
};

const ListItem: FC<ListItemProps> = ({
  address,
  amount,
  created_at,
  landlord_details,
  bank_details,
  invoice_id,
  ivr,
  tenantDetails,
  updated_at,
  type,
  propertyId,
}) => {
  const [createPayment, { loading: createPaymentLoading }] = useMutation<
    CreatePayment,
    CreatePaymentVariables
  >(CREATE_PAYMENT);

  const handleMarkAsPaidClick = useCallback(async () => {
    await createPayment({
      variables: {
        invoice_id,
        status: invoice_api_PaymentStatusEnum.PAYMENT_SUCCESS,
      },
      refetchQueries: ["PayoutsGetAllInvoices"],
    });
  }, [createPayment, invoice_id]);

  return (
    <Tr>
      <Td>
        <Link className="link" to={`/listing/${propertyId}/edit`}>
          {address}
        </Link>
      </Td>
      <Td>
        {landlord_details?.first_name} {landlord_details?.last_name}
      </Td>
      <Td>
        {tenantDetails?.first_name} {tenantDetails?.last_name}
      </Td>
      <Td>{ivr}</Td>
      <Td>{formatDateTime(created_at)}</Td>
      <Td>{formatDateTime(addDays(new Date(updated_at), 1))}</Td>
      <Td>{amount}</Td>
      <Td>{type === "rent-payout" ? "RENT" : "other"}</Td>
      <Td>
        {bank_details?.account_name}
        {(bank_details?.sort_code || bank_details?.account_number) && (
          <>
            <br />
            {bank_details?.sort_code} | {bank_details?.account_number}
          </>
        )}
        {bank_details?.personal_reference && (
          <>
            <br />
            {bank_details?.personal_reference}
          </>
        )}
      </Td>
      <Td colSpan={2}>
        <AntdButton
          block
          loading={createPaymentLoading}
          onClick={handleMarkAsPaidClick}
          type="link"
        >
          {createPaymentLoading ? "Loading" : "Mark as paid"}
        </AntdButton>
      </Td>
    </Tr>
  );
};

export default ListItem;
