import {
  common_api_generic_query_QueryFilterOperatorEnum as FilterOperatorEnum,
  common_api_generic_query_QueryParamsFilterInput as ParamsFilterInput,
} from "../../globalTypes";

export type FilterProps = {
  operator: FilterOperatorEnum;
  field: string;
  value: string | string[];
};

export const makeFilters = ({ values, filters }): ParamsFilterInput[] =>
  filters
    .filter(({ fields, key, operator }) => {
      if (operator === FilterOperatorEnum.RANGE && fields.includes("created")) {
        return values["paymentDateMin"] && values["paymentDateMax"];
      }
      if (
        operator === FilterOperatorEnum.RANGE &&
        fields.includes("scheduled")
      ) {
        return values["payoutDateMin"] && values["payoutDateMax"];
      }
      if (key.includes(".")) {
        const dotKey = key.split(".")[0];
        return values[dotKey];
      }

      return values[key];
    })
    .map(({ key, operator, fields, transformation, not }) => {
      if (operator === FilterOperatorEnum.RANGE) {
        return {
          operator: FilterOperatorEnum[operator],
          fields,
          value: fields.includes("created")
            ? [values["paymentDateMin"], values["paymentDateMax"]]
            : fields.includes("scheduled")
            ? [values["payoutDateMin"], values["payoutDateMax"]]
            : [],
          transformation,
        };
      }

      if (key.includes(".")) {
        const dotKey = key.split(".")[0];
        return {
          operator: FilterOperatorEnum[operator],
          fields,
          value: values[dotKey]["value"].toString(),
          transformation,
          not,
        };
      }

      return {
        operator: FilterOperatorEnum[operator],
        fields,
        value: values[key].toString(),
        transformation,
        not,
      };
    });
