import React, { FC, useState } from "react";

import { PrimaryButton } from "../../../ui/atoms/Button";
import EmailLink from "../../../ui/atoms/EmailLink";
import {
  StatusDanger,
  StatusSuccess,
  UserDetails as Col,
  UserFlexRow as Row,
  UserItemName as Name,
  UserItemValue as Value,
} from "../../../ui/atoms/UserCard";
import {
  UserFormGroup as Group,
  UserFormRow as FormRow,
} from "../../../ui/atoms/UserForm";
import ChangePhoneNumberModal from "../ChangePhoneNumberModal";
import { GetUserInfo_admin_User_contact } from "../graphql/queries/__generated__/GetUserInfo";

type Props = {
  contact: GetUserInfo_admin_User_contact | null | undefined;
  onComplete: () => void;
  userId: string | undefined;
};

const Contacts: FC<Props> = ({ contact, onComplete, userId }) => {
  const [showPhoneModal, setShowPhoneModal] = useState(false);

  if (!contact || !userId) {
    return null;
  }
  const { email_primary, phone_primary, contact_status } = contact;

  return (
    <>
      <Group>
        <h3>Contact details</h3>
        <FormRow>
          <Row>
            <Col>
              <Name>mashroom ID</Name>
              <Value>
                {email_primary}
                <br />
                {contact_status?.email_verified ? (
                  <StatusSuccess>Verified</StatusSuccess>
                ) : (
                  <StatusDanger>Not verified</StatusDanger>
                )}
              </Value>
            </Col>
            <Col>
              <EmailLink
                className="link-button"
                href={`mailto:${email_primary}`}
              >
                <PrimaryButton>New E-mail</PrimaryButton>
              </EmailLink>
            </Col>
          </Row>
        </FormRow>
        <FormRow>
          <Row>
            <Col>
              <Name>Phone number</Name>
              <Value>
                {!phone_primary || phone_primary === "" ? "N/A" : phone_primary}
                <br />
                {contact_status?.phone_verified ? (
                  <StatusSuccess>Verified</StatusSuccess>
                ) : (
                  <StatusDanger>Not verified</StatusDanger>
                )}
              </Value>
            </Col>
            <Col>
              <PrimaryButton onClick={() => setShowPhoneModal(true)}>
                Change
              </PrimaryButton>
            </Col>
          </Row>
        </FormRow>
      </Group>

      {showPhoneModal && (
        <ChangePhoneNumberModal
          onCancel={() => setShowPhoneModal(false)}
          onSubmit={() => {
            setShowPhoneModal(false);
            onComplete();
          }}
          userId={userId}
        />
      )}
    </>
  );
};

export default Contacts;
