import React, { FC } from "react";

import format from "date-fns/format";

import {
  UserAvatar,
  UserDetails,
  UserFlexRow,
  UserItemName as Name,
  UserItemValue as Value,
  UserLastUpdate,
} from "../../../ui/atoms/UserCard";
import {
  UserFormGroup as Group,
  UserFormRow as FormRow,
} from "../../../ui/atoms/UserForm";
import { GetUserInfo_admin_User_details } from "../graphql/queries/__generated__/GetUserInfo";

type Props = {
  lastLogin: string | null | undefined;
  details: GetUserInfo_admin_User_details | null | undefined;
};

const Details: FC<Props> = ({ lastLogin, details }) => {
  const avatarImage = details?.avatar?.id
    ? `/media/thumb-${details?.avatar?.id}`
    : `https://placekitten.com/190/190`;

  return (
    <Group>
      <UserFlexRow>
        <UserAvatar>
          <div
            className="avatar avatar_medium"
            style={{
              backgroundImage: `url(${avatarImage})`,
            }}
          />
          <UserLastUpdate>
            last seen
            <br />
            <b>
              {lastLogin ? format(new Date(lastLogin), "d MMMM, yyyy") : "N/A"}
            </b>
          </UserLastUpdate>
        </UserAvatar>
        <UserDetails>
          <FormRow>
            <Name>First name</Name>
            <Value>{details?.first_name || "N/A"}</Value>
          </FormRow>
          <FormRow>
            <Name>Last name</Name>
            <Value>{details?.last_name || "N/A"}</Value>
          </FormRow>
          <FormRow>
            <Name>Birthday</Name>
            <Value>
              {details?.birthday
                ? format(new Date(details?.birthday), "d MMMM, yyyy")
                : "N/A"}
            </Value>
          </FormRow>
        </UserDetails>
      </UserFlexRow>
    </Group>
  );
};

export default Details;
