import React, { FC } from "react";

import {
  UserDetails as Col,
  UserFlexRow as Row,
  UserItemName as Name,
  UserItemValue as Value,
} from "../../../ui/atoms/UserCard";
import {
  UserFormGroup as Group,
  UserFormRow as FormRow,
} from "../../../ui/atoms/UserForm";
import { GetUserInfo_admin_User_location } from "../graphql/queries/__generated__/GetUserInfo";

type Props = {
  location: GetUserInfo_admin_User_location | null | undefined;
};

const HomeAddress: FC<Props> = ({ location }) => {
  if (!location) {
    return null;
  }

  const {
    address1,
    address2,
    address3,
    address4,
    street,
    building,
    city,
    postcode,
    country,
  } = location;

  const homeAddress = [address1, address2, address3, address4]
    .filter(Boolean)
    .join(", ");

  return (
    <Group>
      <FormRow>
        <Name>Home address</Name>
        <Value>{homeAddress !== "" ? homeAddress : "N/A"}</Value>
      </FormRow>
      <FormRow>
        <Row>
          {((street && street !== "") || (building && building !== "")) && (
            <Col>
              <Name>Street / Building</Name>
              <Value>{[street, building].filter(Boolean).join(", ")}</Value>
            </Col>
          )}
          <Col>
            <Name>City / Town</Name>
            <Value>{city && city !== "" ? city : "N/A"}</Value>
          </Col>
          <Col>
            <Name>Postcode</Name>
            <Value>{postcode && postcode !== "" ? postcode : "N/A"}</Value>
          </Col>
          <Col>
            <Name>Country</Name>
            <Value>{country && country !== "" ? country : "N/A"}</Value>
          </Col>
        </Row>
      </FormRow>
    </Group>
  );
};

export default HomeAddress;
