import React, { FC, useCallback, useState } from "react";

import { format } from "date-fns";

import { PrimaryButton } from "../../../../ui/atoms/Button";
import { Table, TdInner, ThInner } from "../../../../ui/atoms/Table";
import {
  UserDetails as Col,
  UserFlexRow as Row,
  UserItemValue as Value,
} from "../../../../ui/atoms/UserCard";
import { UserFormGroup as Group } from "../../../../ui/atoms/UserForm";
import { getPersonFullName } from "../../../../util";
import { GetUserInfo_admin_User_verification_info_sessions } from "../../graphql/queries/__generated__/GetUserInfo";
import { OverrideVerificationSessionModal } from "./OverrideVerificationSessionModal";
import { IdentityVerificationProps } from "./types";

export const IdentityVerification: FC<IdentityVerificationProps> = ({
  user,
  refetch,
}) => {
  const sessions = user.verification_info.sessions;
  const [showModal, setShowModal] = useState<{
    show: boolean;
    session: GetUserInfo_admin_User_verification_info_sessions | null;
  }>({ show: false, session: null });

  const handleCloseModal = useCallback(
    () => setShowModal({ show: false, session: null }),
    []
  );

  return (
    <Group>
      <h3>Identity Verification</h3>
      <Row>
        <Col>
          <Value>
            Status:&nbsp;
            {user.verification_info.is_verified ? (
              <span style={{ color: "green" }}>Verified</span>
            ) : (
              <span>Not verified</span>
            )}
            <br />
            <br />
          </Value>
        </Col>
      </Row>
      {sessions && (
        <Table>
          <thead>
            <tr>
              <ThInner>Created at</ThInner>
              <ThInner>Status</ThInner>
              <ThInner>Desicion code</ThInner>
              <ThInner>Notes</ThInner>
              <ThInner>Full name</ThInner>
              <ThInner>Reason</ThInner>
              <ThInner>Reason code</ThInner>
              <ThInner>Edit</ThInner>
            </tr>
          </thead>
          <tbody>
            {sessions?.map((session, key) => (
              <tr key={key}>
                <TdInner>
                  {format(
                    new Date(
                      session.updated_at
                        ? session.updated_at
                        : session.created_at
                    ),
                    "dd MMM yyyy HH:mm"
                  )}
                </TdInner>
                <TdInner>{session.status}</TdInner>
                <TdInner>{session.decision_code}</TdInner>
                <TdInner>{session.notes}</TdInner>
                <TdInner>
                  {getPersonFullName({
                    firstName: session.first_name,
                    lastName: session.last_name,
                  })}
                </TdInner>
                <TdInner>{session.reason}</TdInner>
                <TdInner>{session.reason_code}</TdInner>
                {session.is_admin ? (
                  <TdInner
                    className="link"
                    onClick={() => {
                      setShowModal({ show: true, session });
                    }}
                  >
                    Edit
                  </TdInner>
                ) : (
                  <TdInner />
                )}
              </tr>
            ))}
          </tbody>
        </Table>
      )}
      <PrimaryButton
        onClick={() => setShowModal({ show: true, session: null })}
      >
        Add Override Session
      </PrimaryButton>
      {showModal.show && (
        <OverrideVerificationSessionModal
          onCancel={() => handleCloseModal()}
          onSubmit={() => {
            handleCloseModal();
            refetch();
          }}
          user={user}
          session={showModal.session}
        />
      )}
    </Group>
  );
};
