import React, { FC, useCallback } from "react";

import { useQuery } from "react-apollo";

import Spinner from "../../../ui/atoms/Spinner";
import { SimpleMessage } from "../../../ui/molecules/ErrorMessage";
import {
  GetUserInfo,
  GetUserInfoVariables,
} from "../graphql/queries/__generated__/GetUserInfo";
import USER_INFO from "../graphql/queries/getUserInfo.graphql";
import Account from "./Account";
import Associated from "./Associated";
import BankDetails from "./BankDetails";
import Contacts from "./Contacts";
import UserDetails from "./Details";
import HomeAddress from "./HomeAddress";
import { IdentityVerification } from "./IdentityVerification";
import UserPayments from "./Payments";
import UserDetailsMessages from "./UserDetailsMessages";

import css from "./index.module.css";

type Props = {
  userId: string | undefined;
};

const Details: FC<Props> = ({ userId }) => {
  const { data, error, loading, refetch } = useQuery<
    GetUserInfo,
    GetUserInfoVariables
  >(USER_INFO, {
    variables: {
      id: userId,
    },
    skip: !userId,
  });
  const user = data?.admin?.User;
  const handleComplete = useCallback(() => refetch(), [refetch]);

  return (
    <>
      {loading ? (
        <div className={css.loading}>
          <Spinner />
        </div>
      ) : error ? (
        <SimpleMessage>{error.message}</SimpleMessage>
      ) : user ? (
        <>
          <UserDetails details={user.details} lastLogin={user.last_login} />
          <HomeAddress location={user.location} />
          <Account
            createdAt={user.created_at}
            creation_type={user.creation_type}
          />
          <IdentityVerification user={user} refetch={refetch} />
          <BankDetails
            bankDetails={user.bank_details}
            onComplete={handleComplete}
            userId={userId}
          />
          <Contacts
            contact={user.contact}
            onComplete={handleComplete}
            userId={userId}
          />
          <UserDetailsMessages onComplete={handleComplete} userId={userId} />
          {userId ? <UserPayments userId={userId} /> : null}
          {userId ? <Associated userId={userId} /> : null}
        </>
      ) : (
        "Something was wrong, Can't load user data..."
      )}
    </>
  );
};

export default Details;
