import { useCallback } from "react";

import { Modal } from "antd";
import { useMutation } from "react-apollo";
import { useHistory } from "react-router-dom";

import { Routes } from "../../../constants/routes";
import {
  DeleteUser,
  DeleteUserVariables,
} from "../graphql/mutations/__generated__/DeleteUser";
import DELETE_USER from "../graphql/mutations/deleteUser.graphql";

const useDeleteUser = (userId: any) => {
  const history = useHistory();

  const [deleteUser, { loading }] = useMutation<
    DeleteUser,
    DeleteUserVariables
  >(DELETE_USER);

  const handleOkClick = useCallback(async () => {
    try {
      const { data } = await deleteUser({
        variables: {
          id: userId,
        },
      });

      if (data?.admin?.deleteUser?.success) {
        history.push(Routes.Users);
        Modal.destroyAll();
      }
    } catch (error) {
      // eslint-disable-next-line no-console
      console.error("Delete user error:", error);
    }
  }, [deleteUser, history, userId]);

  const showConfirmationModal = useCallback(() => {
    Modal.confirm({
      centered: true,
      maskClosable: true,
      title: "Delete user",
      content: "Are you sure you want to delete user?",
      okButtonProps: {
        danger: true,
      },
      okText: "Delete",
      onOk: handleOkClick,
    });
  }, [handleOkClick]);

  return {
    loading,
    showConfirmationModal,
  };
};

export default useDeleteUser;
