import { ComponentProps } from "react";

import styled from "@emotion/styled";

import { colors } from "../../theme";

export const SelectContainer = styled.div`
  position: relative;
`;

export const Input = styled.input<ComponentProps<"input">>`
  width: 100%;
  height: ${({ height }) => height || "2.3em"};
  border-radius: 0.5em;
  border-color: ${colors.blueyGrey};
  border-style: solid;
  border-width: 0.12em;
  padding: 1em;
  font-size: 1em;
  font-weight: 500;
  -webkit-appearance: none;
  -moz-appearance: none;

  :not([readonly]):focus {
    border-color: ${colors.black};
  }

  :is([readonly]) {
    background-color: ${colors.serviceLightGrey};

    :hover {
      cursor: not-allowed;
    }
  }

  &[data-invalid="true"] {
    border-color: ${colors.mashPaleRed};
  }
`;

export const Options = styled.ul<{ height }>`
  list-style: none;
  padding: 0.5em;
  margin-top: 0.5em;
  position: absolute;
  z-index: 200;
  width: 100%;
  background: ${colors.white};
  line-height: ${({ height }) => height || "2.3em"};
  max-height: 20em;
  border-radius: 0.5em;
  border-style: solid;
  border-color: ${colors.blueyGrey};
  overflow: auto;
  font-size: 1em;
  font-weight: 600;
`;

export const Option = styled.li`
  padding: 0;

  a {
    display: block;
    padding: 0 0.5em 0 0.5em;
    text-decoration: none;
    color: ${colors.black};
  }

  a:hover {
    background: ${colors.mashPaleRedHover};
    color: ${colors.white};
    border-radius: 0.5em;
    border-style: none;
  }
`;

export const InputGroup = styled.div`
  display: flex;
  position: relative;
`;
export const SpinnerContainer = styled.div`
  position: absolute;
  right: 0;
`;
