import React, { FC } from "react";

import {
  CardCvcElement,
  CardExpiryElement,
  CardNumberElement,
} from "@stripe/react-stripe-js";
import { StripeCardElementChangeEvent } from "@stripe/stripe-js";
import { FieldRenderProps } from "react-final-form";

import StripeLogo from "../StripeLogo/stripeLogo";
import {
  ElementContainer,
  ElementsContainer,
  StripeInputStyle,
  StripeLogoContainer,
  StripePaymentContainer,
} from "./styles";

const STRIPE_PAYMENT_INPUT_PLACEHOLDER = {
  CARD_NUMBER: "Card number",
  CARD_NUMBER_DIGITS: "0000 0000 0000 0000",
  CARD_EXPIRY: "MM/YY",
  CARD_CVC: "CVV",
};

export const STRIPE_PAYMENT_INPUT_OPTIONS = {
  CARD_NUMBER: {
    style: StripeInputStyle,
    placeholder: STRIPE_PAYMENT_INPUT_PLACEHOLDER.CARD_NUMBER_DIGITS,
  },
  CARD_EXPIRY: {
    style: StripeInputStyle,
    placeholder: STRIPE_PAYMENT_INPUT_PLACEHOLDER.CARD_EXPIRY,
  },
  CARD_CVC: {
    style: StripeInputStyle,
    placeholder: STRIPE_PAYMENT_INPUT_PLACEHOLDER.CARD_CVC,
  },
};

type StripePaymentProps = FieldRenderProps<
  StripeCardElementChangeEvent,
  HTMLInputElement
>;

const StripePayment: FC<StripePaymentProps> = ({ input, meta }) => (
  <StripePaymentContainer>
    <ElementsContainer>
      <ElementContainer type={"number"}>
        <CardNumberElement
          {...input}
          onChange={(e) => input.onChange(e)}
          options={STRIPE_PAYMENT_INPUT_OPTIONS.CARD_NUMBER}
        />
      </ElementContainer>

      <ElementContainer type={"expire"}>
        <CardExpiryElement
          {...input}
          onChange={(e) => input.onChange(e)}
          options={STRIPE_PAYMENT_INPUT_OPTIONS.CARD_EXPIRY}
        />
      </ElementContainer>
      <ElementContainer type={"cvc"}>
        <CardCvcElement
          {...input}
          onChange={(e) => input.onChange(e)}
          options={STRIPE_PAYMENT_INPUT_OPTIONS.CARD_CVC}
        />
      </ElementContainer>
    </ElementsContainer>
    <StripeLogoContainer>
      <StripeLogo />
    </StripeLogoContainer>
  </StripePaymentContainer>
);

export default StripePayment;
