import { ServiceCodes } from "../../listing/constants";

export interface ExtrasProduct {
  id: string;
  code: string;
  title: string;
  price: number;
  tax: number;
  referenceID: string;
  remote_sales_prices: number[];
  remote_sales_taxes: number[];
}

export interface PropertyProduct {
  id?: string;
  code: string;
  type: ProductType;
  status: ProductStatus;
  title: string;
  price: number;
  tax: number;
  referenceID: string;
  selected?: boolean;
  lastSale?: ProductSale;
  insuranceDetails?: InsuranceDetails;
  gasSafetyDetails?: GasSafetyDetails;
  inventoryDetails?: InventoryDetails;
  calculatePrice: (prod: PropertyProduct) => Promise<void>;
  remote_sales_prices: number[];
  remote_sales_taxes: number[];
}

export interface ProductSale {
  code: string;
  status: ProductStatus;
  saleDate: number;
  startDate: number;
  endDate: number;
}

export interface InsuranceDetails {
  startDate?: string;
  rentAmount?: number;
}

export interface GasSafetyDetails {
  boiler: boolean;
  selected_index?: number;
}

export enum FurnishedType {
  UNFURNISHED = "Unfurnished",
  FURNISHED = "Furnished",
}

export interface InventoryDetails {
  furnishedType?: FurnishedType;
  bedroomsNum?: number;
  checkIn?: boolean;
}

export enum ProductType {
  LEGAL_EXPENSES_INSURANCE = "Legal Expenses Insurance",
  HOME_EMERGENCY_INSURANCE = "Home Emergency Insurance",
  RENT_GUARANTEE_INSURANCE = "Rent Guarantee Insurance",
  ENERGY_PERFORMANCE_CERTIFICATE = "Energy Performance Certificate",
  ELECTRICAL_INSTALLATION_REPORT = "Electrical Installation Report",
  GAS_SAFETY = "Gas Safety",
  PROFESSIONAL_PHOTOGRAPHY_AND_FLOOR_PLAN = "Professional Photography and Floor Plan",
  INVENTORY = "Inventory",
}

export const ProductCodesByType: Map<ProductType, Array<string>> = new Map([
  [
    ProductType.LEGAL_EXPENSES_INSURANCE,
    [ServiceCodes.landlord_legal_expenses_insurance],
  ],
  [
    ProductType.HOME_EMERGENCY_INSURANCE,
    [ServiceCodes.landlord_home_emergency_insurance],
  ],
  [
    ProductType.RENT_GUARANTEE_INSURANCE,
    [ServiceCodes.landlord_rent_guarantee_insurance],
  ],
  [
    ProductType.ENERGY_PERFORMANCE_CERTIFICATE,
    [ServiceCodes.landlord_epc_certificate],
  ],
  [
    ProductType.ELECTRICAL_INSTALLATION_REPORT,
    [ServiceCodes.landlord_eic_report],
  ],
  [
    ProductType.GAS_SAFETY,
    [
      ServiceCodes.landlord_gas_certificate,
      ServiceCodes.landlord_gas_safety_boiler_service,
    ],
  ],
  [
    ProductType.PROFESSIONAL_PHOTOGRAPHY_AND_FLOOR_PLAN,
    [ServiceCodes.landlord_photographs_floor_plans],
  ],
  [
    ProductType.INVENTORY,
    [ServiceCodes.landlord_inventory, ServiceCodes.landlord_inventory_check_in],
  ],
]);

export enum ProductStatus {
  UNKNOWN,
  PENDING,
  PAID,
}
