import React, { useState } from "react";

import { useQuery } from "react-apollo";
import { useHistory, useLocation } from "react-router-dom";

import {
  LeadGet,
  LeadGetVariables,
} from "../../graphql/queries/__generated__/LeadGet";
import LEAD_GET from "../../graphql/queries/LeadGet.graphql";
import { AccountDetails } from "../../models/account";
import { MainContainer } from "../../styles";
import LeadSearchProgress from "./LeadSearchProgress";
import { ErrorsContainer } from "./styles";

const UNKNOWN_LEAD_ID = "unknown";
export const useURLQuery = () => {
  const { search } = useLocation();
  return React.useMemo(() => new URLSearchParams(search), [search]);
};

const LeadSearchPage = () => {
  const query = useURLQuery();
  const leadId = query.get("leadId") || UNKNOWN_LEAD_ID;

  const history = useHistory();

  const [error, setError] = useState<string>();

  useQuery<LeadGet, LeadGetVariables>(LEAD_GET, {
    variables: { lead_id: leadId },
    skip: leadId === UNKNOWN_LEAD_ID,
    onCompleted: (data) => forwardToUserDetailsPage(data, history),
    onError: (error) => setError(String(error)),
  });

  return (
    <MainContainer>
      {!error && <LeadSearchProgress leadId={leadId}></LeadSearchProgress>}
      {error && <ErrorsContainer>{error}</ErrorsContainer>}
    </MainContainer>
  );
};

export default LeadSearchPage;

const forwardToUserDetailsPage = (data: LeadGet, history) => {
  const lead = data?.closecom?.lead?.get?.lead;
  let accountDetails;

  if (lead) {
    const names = lead.name.split(" ");
    accountDetails = {
      firstName: names.length > 0 ? names[0] : "",
      secondName: names.length > 1 ? names[1] : "",
      email:
        lead.contacts && lead.contacts?.length > 0
          ? lead.contacts[0]?.email || ""
          : "",
      phone:
        lead.contacts && lead.contacts?.length > 0
          ? lead.contacts[0]?.phone || ""
          : "",
    } as AccountDetails;
  }

  history.push({
    pathname: "/remote-sales/account-details",
    state: accountDetails,
  });
};
