import React, { FC, ReactNode } from "react";

import { Field, Form } from "react-final-form";

import { required } from "../../../../../../util/validations";
import { InputField } from "../../../../components/Input";
import Spinner from "../../../../components/Spinner";
import { Address } from "../../../../models/address";
import { colors } from "../../../../theme";
import {
  AddressFormContainer,
  ButtonsContainer,
  ErrorsContainer,
  InputGroup,
  Label,
  SpinnerContainer,
} from "./styles";

type AddressFormProps = {
  address?: Address;
  onSubmit?: (address: Address) => void;
  errors?: Array<String>;
  buttons?: (submitting: boolean, valid: boolean) => ReactNode;
};

const AddressForm: FC<AddressFormProps> = ({
  address,
  onSubmit,
  buttons,
  errors,
}) => (
  <Form<Address>
    initialValues={address}
    onSubmit={(values) => (onSubmit ? onSubmit(values) : {})}
    render={({ submitting, valid, handleSubmit }) => (
      <form
        onSubmit={(e) => {
          e.preventDefault();
          handleSubmit();
        }}
      >
        <AddressFormContainer>
          <InputGroup>
            <Label htmlFor="flat">Flat number:</Label>
            <Field
              name="flat"
              readOnly={submitting}
              defaultValue={address?.flat}
            >
              {InputField}
            </Field>
          </InputGroup>

          <InputGroup>
            <Label htmlFor="building">Building/House name:</Label>
            <Field
              name="building"
              readOnly={submitting}
              defaultValue={address?.building}
              validate={required("'Building' is required field")}
            >
              {InputField}
            </Field>
          </InputGroup>

          <InputGroup>
            <Label htmlFor="street">Street:</Label>
            <Field
              name="street"
              readOnly={submitting}
              defaultValue={address?.street}
              validate={required("'Street' is required field")}
            >
              {InputField}
            </Field>
          </InputGroup>

          <InputGroup>
            <Label htmlFor="city">City / Town:</Label>
            <Field
              name="city"
              readOnly={submitting}
              defaultValue={address?.city}
              validate={required("'City / Town' is required field")}
            >
              {InputField}
            </Field>
          </InputGroup>

          <InputGroup>
            <Label htmlFor="country">Country:</Label>
            <Field
              name="country"
              readOnly={submitting}
              defaultValue={address?.country}
              validate={required("'Country' is required field")}
            >
              {InputField}
            </Field>
          </InputGroup>

          <InputGroup>
            <Label htmlFor="postcode">Postcode:</Label>
            <Field
              name="postcode"
              readOnly={submitting}
              defaultValue={address?.postcode}
              validate={required("'Postcode' is required field")}
            >
              {InputField}
            </Field>
          </InputGroup>
        </AddressFormContainer>
        {!!errors?.length && (
          <ErrorsContainer>{errors.join(",")}</ErrorsContainer>
        )}
        {!!buttons?.length && (
          <ButtonsContainer>
            {submitting && (
              <SpinnerContainer>
                <Spinner color={colors.white} size="md" />
              </SpinnerContainer>
            )}
            {buttons(submitting, valid)}
          </ButtonsContainer>
        )}
      </form>
    )}
  ></Form>
);

export default AddressForm;
