import React, { FC, useState } from "react";

import Button from "../../../components/Button";
import Modal from "../../../components/Modal";
import { Address } from "../../../models/address";
import AddressSelect from "../AddressSelect";
import AddressForm from "./AddressForm";
import { AddressContainer } from "./styles";

type AddressModalProps = {
  title: string;
  onSubmit: (addrUrl: string, addr: Address) => void;
  onCancel: () => void;
};

const AddressModal: FC<AddressModalProps> = ({ title, onSubmit, onCancel }) => {
  const [address, setAddress] = useState<{ url: string; addr: Address }>();

  return (
    <Modal title={title} onClose={onCancel} width={"40%"}>
      <AddressContainer>
        <AddressSelect onSelect={(url, addr) => setAddress({ url, addr })} />
        {address && (
          <AddressForm
            address={address.addr}
            onSubmit={(formData) => onSubmit(address.url, formData)}
            buttons={(submitting, valid) => (
              <Button
                type="submit"
                disabled={submitting || !valid}
                width={"100%"}
              >
                {!submitting && "Submit"}
              </Button>
            )}
          />
        )}
      </AddressContainer>
    </Modal>
  );
};

export default AddressModal;
