import React, { FC, useMemo, useState } from "react";

import { withApollo, WithApolloClient } from "react-apollo";

import Select from "../../../components/Select";
import { Address, AddressOption } from "../../../models/address";
import { createAddressService } from "../../../service/address";
import { AddressContainer } from "./styles";

type AddressSelectProps = WithApolloClient<{
  onSelect?: (addrUrl: string, addr: Address) => void;
}>;

const AddressSelect: FC<AddressSelectProps> = ({ client, onSelect }) => {
  const addrService = useMemo(() => createAddressService(client), [client]);

  const [options, setOptions] = useState<AddressOption[]>([]);

  const onFilter = async (filterLine: string): Promise<void> => {
    if (!filterLine) {
      return;
    }

    setOptions(await addrService.getSugestions(filterLine));
  };

  const onOptionSelect = async (option: AddressOption): Promise<void> =>
    onSelect &&
    onSelect(option.url, await addrService.getAddressByUrl(option.url));

  return (
    <AddressContainer>
      <Select<AddressOption>
        placeholder="Enter address line or postcode..."
        options={options}
        displayAttr={"address"}
        onSelect={onOptionSelect}
        onFilter={onFilter}
      />
    </AddressContainer>
  );
};

export default withApollo<AddressSelectProps>(AddressSelect);
