import React, { FC, useState } from "react";

import { Address } from "../../../models/address";
import {
  CardContainer,
  CardHeader,
  CardHeaderLink,
  CardHeaderLinks,
  CardTitle,
} from "../../../styles";
import AddressModal from "../AddressModal";
import { AddressDetails, AddressLine } from "./styles";

type CorrespondenceAddressProps = {
  address?: Address;
  onChange?: (address: Address) => void;
};

const CorrespondenceAddress: FC<CorrespondenceAddressProps> = ({
  address,
  onChange,
}) => {
  const [editAddressVisible, setEditAddressVisible] = useState<boolean>(false);

  return (
    <>
      <CardContainer>
        <CardHeader>
          <CardTitle>Correspondence Address</CardTitle>
          <CardHeaderLinks>
            <CardHeaderLink onClick={() => setEditAddressVisible(true)}>
              Edit
            </CardHeaderLink>
          </CardHeaderLinks>
        </CardHeader>
        {address && (
          <AddressDetails>
            <AddressLine>
              {address.flat} {address.address}
            </AddressLine>
            <AddressLine>{address.postcode}</AddressLine>
            <AddressLine>{address.city}</AddressLine>
            <AddressLine>{address.country}</AddressLine>
          </AddressDetails>
        )}
      </CardContainer>

      {editAddressVisible && (
        <AddressModal
          title={"Edit Corresponding Address"}
          onSubmit={(_, addr) => {
            setEditAddressVisible(false);
            if (onChange) {
              onChange(addr);
            }
          }}
          onCancel={() => setEditAddressVisible(false)}
        ></AddressModal>
      )}
    </>
  );
};

export default CorrespondenceAddress;
