import React, { FC } from "react";

import Checkbox from "../../../../../components/Checkbox";
import {
  FurnishedType,
  ProductType,
  PropertyProduct,
} from "../../../../../models/product";
import {
  ProductDetailsCheckboxValue,
  ProductDetailsInputValue,
  ProductDetailsLabel,
  ProductDetailsSelect,
} from "../styles";
import { ProductAttrInput } from "./styles";

type ProductAttributesProps = {
  product: PropertyProduct;
  onChange: (prod: PropertyProduct) => void;
};

const ProductAttributes: FC<ProductAttributesProps> = ({
  product,
  onChange,
}) => (
  <>
    {product.type === ProductType.RENT_GUARANTEE_INSURANCE && (
      <>
        <ProductDetailsLabel>Rent amount</ProductDetailsLabel>
        <ProductDetailsInputValue>
          <ProductAttrInput
            type={"number"}
            width={"3.5rem"}
            defaultValue={product.insuranceDetails?.rentAmount}
            onChange={(evt) => {
              product.insuranceDetails = {
                ...product.insuranceDetails,
                rentAmount: Number(evt.target.value),
              };
              onChange(product);
            }}
          />
        </ProductDetailsInputValue>
      </>
    )}

    {[
      ProductType.HOME_EMERGENCY_INSURANCE,
      ProductType.LEGAL_EXPENSES_INSURANCE,
      ProductType.RENT_GUARANTEE_INSURANCE,
    ].includes(product.type) && (
      <>
        <ProductDetailsLabel>Start date</ProductDetailsLabel>
        <ProductDetailsInputValue>
          <ProductAttrInput
            type={"date"}
            defaultValue={product.insuranceDetails?.startDate}
            onChange={(evt) => {
              product.insuranceDetails = {
                ...product.insuranceDetails,
                startDate: evt.target.value,
              };
              onChange(product);
            }}
          ></ProductAttrInput>
        </ProductDetailsInputValue>
      </>
    )}

    {product.type === ProductType.GAS_SAFETY && (
      <>
        <ProductDetailsLabel>Add Boiler (+£20)</ProductDetailsLabel>
        <ProductDetailsCheckboxValue>
          <Checkbox
            defaultChecked={product.gasSafetyDetails?.boiler}
            onChange={() => {
              product.gasSafetyDetails = {
                ...product.gasSafetyDetails,
                boiler: !product.gasSafetyDetails?.boiler,
              };
              onChange(product);
            }}
          ></Checkbox>
        </ProductDetailsCheckboxValue>
      </>
    )}

    {product.type === ProductType.INVENTORY && (
      <>
        <ProductDetailsLabel>Property furnished state</ProductDetailsLabel>
        <ProductDetailsCheckboxValue>
          <ProductDetailsSelect
            defaultValue={product.inventoryDetails?.furnishedType}
            onChange={(evt) => {
              product.inventoryDetails = {
                ...product.inventoryDetails,
                furnishedType: (evt.target.value as unknown) as FurnishedType,
              };
              onChange(product);
            }}
          >
            {Object.entries(FurnishedType).map(([code, title]) => (
              <option key={code}>{title}</option>
            ))}
          </ProductDetailsSelect>
        </ProductDetailsCheckboxValue>

        <ProductDetailsLabel>Bedrooms</ProductDetailsLabel>
        <ProductDetailsCheckboxValue>
          <ProductDetailsSelect
            defaultValue={product.inventoryDetails?.bedroomsNum || 0}
            onChange={(evt) => {
              product.inventoryDetails = {
                ...product.inventoryDetails,
                bedroomsNum: Number(evt.target.value),
              };
              onChange(product);
            }}
          >
            {Array.from({ length: 5 }, (_, i) => 1 + i).map((num) => (
              <option key={num}>{num}</option>
            ))}
          </ProductDetailsSelect>
        </ProductDetailsCheckboxValue>

        <ProductDetailsLabel>Check In</ProductDetailsLabel>
        <ProductDetailsCheckboxValue>
          <Checkbox
            defaultChecked={!!product.inventoryDetails?.checkIn}
            onChange={() => {
              product.inventoryDetails = {
                ...product.inventoryDetails,
                checkIn: !product.inventoryDetails?.checkIn,
              };
              onChange(product);
            }}
          ></Checkbox>
        </ProductDetailsCheckboxValue>
      </>
    )}
  </>
);

export default ProductAttributes;
