import styled from "@emotion/styled";

import { ButtonProps } from "../../../components/Button";
import { PropertyStatus } from "../../../models/property";
import { colors } from "../../../theme";

export const NewPropertyLink = styled.a`
  color: ${colors.mashPaleRed};
  font-weight: 500;
  cursor: pointer;

  :focus,
  :active,
  :hover {
    color: ${colors.mashPaleRed};
  }
`;

export const PropertiesContainer = styled.ul`
  padding: 0;
  margin: 0;
`;

export const PropertyItem = styled.li`
  list-style: none;
  padding: 0 0 0 0.5rem;
  margin: 1rem 0 1rem 0;
  border-left: 0.2rem solid ${colors.blueyGrey};
`;

export const PropertyHeader = styled.div`
  display: flex;
  align-items: center;
  gap: 0.5rem;
`;

export const PropertyItemStatus = styled.div<{ status?: PropertyStatus }>`
  border-radius: 0.8em;
  padding: 0 0.5rem 0 0.5rem;
  margin-bottom: 0.5rem;
  width: fit-content;
  font-weight: 600;
  font-size: 0.7rem;
  background-color: ${({ status }) =>
    status === PropertyStatus.VERSION_LET ||
    status === PropertyStatus.VERSION_RENT_COLLECTION
      ? colors.blushGreen
      : colors.creamBrulee};
`;

export const HeaderRight = styled.div`
  display: flex;
  flex-grow: 1;
  justify-content: end;
  gap: 0.5rem;
`;

export const HeaderButton = styled.button<{ active: boolean } & ButtonProps>`
  border-radius: 0.8em;
  border: none;
  padding: 0 0.5rem 0 0.5rem;
  margin-bottom: 0.5rem;
  width: fit-content;
  font-weight: 600;
  font-size: 0.7rem;
  background-color: ${({ active }) =>
    active ? colors.blushGreen : colors.mashPaleRed};
  color: ${({ active }) => (active ? colors.black : colors.white)};
  cursor: pointer;
`;

export const PropertyItemHeader = styled.div`
  font-weight: 600;
`;
