/* 
? TODO: 
=== barnando.akbarto ===
- [ ] Refactor this code, too much bug and hard to maintenance
- [ ] change event emitter to signal base state
*/

import React, { FC, useCallback, useEffect, useMemo, useState } from "react";

import { EventEmitter } from "events";
import { withApollo, WithApolloClient } from "react-apollo";
import { useLocation } from "react-router-dom";

import {
  cardpayment_api_PaymentStatusEnum,
  invoice_api_ProductInput,
  invoice_api_RemoteSalePropertyInput,
  property_api_PropertyFurnitureEnum,
} from "../../../../globalTypes";
import Spinner from "../../components/Spinner";
import StripeLoaderContextProvider from "../../components/StripePayment/StripeLoaderContextProvider";
import {
  CheckCardpaymentReceipt,
  CheckCardpaymentReceiptVariables,
} from "../../graphql/mutations/__generated__/CheckCardpaymentReceipt";
import {
  CreateRemoteSalePayment,
  CreateRemoteSalePaymentVariables,
} from "../../graphql/mutations/__generated__/CreateRemoteSalePayment";
import CHECK_CARD_PAYMENT_RECEIPT from "../../graphql/mutations/CheckCardpaymentReceipt.graphql";
import CREATE_REMOTE_SALE_PAYMENT from "../../graphql/mutations/CreateRemoteSalePayment.graphql";
import { AccountDetails, BankDetails } from "../../models/account";
import { Address } from "../../models/address";
import {
  EMPTY_PAYMENT_DETAILS,
  PaymentDetails,
  PaymentLink,
} from "../../models/payment";
import {
  FurnishedType,
  ProductType,
  PropertyProduct,
} from "../../models/product";
import { Property } from "../../models/property";
import { fixTimezoneOffsetForLocalDate } from "../../models/utils";
import { createAccountService } from "../../service/account";
import { createInvoiceService } from "../../service/invoice";
import { ErrorContainer, MainContainer, SpinnerContainer } from "../../styles";
import { colors } from "../../theme";
import AccountForm from "../AccountDetails/AccountForm";
import Compliance from "./Compliance";
import CorrespondenceAddress from "./CorrespondenceAddress";
import PaymentForm from "./PaymentForm";
import PropertiesList, { PropertiesListEvent } from "./PropertiesList";
import { SuccessfulPayment } from "./styles";

type MainPageProps = WithApolloClient<{}>;

const MainPage: FC<MainPageProps> = ({ client }) => {
  const location = useLocation();
  const query = new URLSearchParams(location.search);
  const userId = query.get("userId") || "";

  const [loading, setLoading] = useState<boolean>(false);
  const [accountDetails, setAccountDetails] = useState<AccountDetails>(
    {} as AccountDetails
  );
  const [properties, setProperties] = useState<Array<Property>>([]);
  const [paymentDetails, setPaymentDetails] = useState<PaymentDetails>(
    EMPTY_PAYMENT_DETAILS
  );
  const [error, setError] = useState<string>();
  const [paymentLink, setPaymentLink] = useState<PaymentLink>();
  const [paymentToken, setPaymentConfirmToken] = useState<string>("");
  const [transactionInProgress, setTransactionInProgress] = useState<boolean>(
    false
  );
  const [paymentSucceeded, setPaymentSucceeded] = useState<boolean>(false);
  const [correspondenceAddress, setCorrespondenceAddress] = useState<Address>(
    {} as Address
  );
  const [complianceChecked, setComplianceChecked] = useState<boolean>(false);

  const accountService = useMemo(() => createAccountService(client), [client]);
  const invoiceService = useMemo(() => createInvoiceService(client), [client]);

  const propertiesListEvents = useMemo<EventEmitter>(
    () => new EventEmitter(),
    []
  );

  useEffect(() => {
    setLoading(true);
    accountService
      .getAccountById(userId)
      .then(setAccountDetails)
      .catch((err) => setError(String(err)))
      .finally(() => setLoading(false));
  }, [accountService, userId]);

  const calcPaymentDetails = useCallback(
    (propsWithSelProds: Array<Property>) => {
      const initDetails: PaymentDetails = { ...EMPTY_PAYMENT_DETAILS };
      const products = propsWithSelProds
        .flatMap((prop) => prop.products || [])
        .filter((prod) => prod.selected);
      const payDetails = products.reduce((acc, prod) => {
        acc.price += prod.price;
        acc.tax += prod.tax;
        return acc;
      }, initDetails);

      payDetails.products = products;
      payDetails.email = accountDetails.email;
      setPaymentDetails(payDetails);
    },
    [accountDetails.email]
  );

  const onPropertiesChange = useCallback(
    (props: Array<Property>) => {
      const propsWithSelectedProds = props.filter((p) =>
        p.products?.some((pd) => pd.selected)
      );
      setProperties(propsWithSelectedProds);
      calcPaymentDetails(propsWithSelectedProds);
    },
    [calcPaymentDetails]
  );

  const prepareProduct = useCallback(
    (prod: PropertyProduct, prop: Property): invoice_api_ProductInput => {
      const startDate = prod.insuranceDetails?.startDate;

      if (
        !startDate &&
        [
          ProductType.HOME_EMERGENCY_INSURANCE,
          ProductType.LEGAL_EXPENSES_INSURANCE,
          ProductType.RENT_GUARANTEE_INSURANCE,
        ].includes(prod.type)
      ) {
        throw new Error("For insurance products 'start date' is required.");
      }

      return {
        service_id: prod.id,
        remote_sales_price: prod.price,
        remote_sales_tax: prod.tax,
        details: {
          property: {
            id: prop.id,
            details: {
              amenity_furniture:
                prod.inventoryDetails?.furnishedType === FurnishedType.FURNISHED
                  ? property_api_PropertyFurnitureEnum.PROPERTY_FURNITURE_FURNISHED
                  : property_api_PropertyFurnitureEnum.PROPERTY_FURNITURE_UNFURNISHED,
              bedrooms_no: prod.inventoryDetails?.bedroomsNum,
            },
          },
          contract: {
            conditions: {
              rent: prod.insuranceDetails?.rentAmount,
            },
          },
          time: {
            start: startDate
              ? fixTimezoneOffsetForLocalDate(startDate, false)
              : "",
          },
        },
      } as invoice_api_ProductInput;
    },
    []
  );

  const prepareProperties = useCallback(
    (
      properties: Array<Property>
    ): Array<invoice_api_RemoteSalePropertyInput> => {
      return properties.map(
        (prop) =>
          ({
            id: prop.id,
            products: (prop?.products || [])
              .filter((prod) => prod.selected)
              .map((prod) => prepareProduct(prod, prop)),
          } as invoice_api_RemoteSalePropertyInput)
      );
    },
    [prepareProduct]
  );

  const createRemoteSalePayment = useCallback(
    async (
      accountDetails: AccountDetails,
      correspondenceAddress: Address,
      paymentLinkId: string,
      bankTransfer: boolean
    ): Promise<string> => {
      const resp = await client.query<
        CreateRemoteSalePayment,
        CreateRemoteSalePaymentVariables
      >({
        query: CREATE_REMOTE_SALE_PAYMENT,
        fetchPolicy: "no-cache",
        variables: {
          userId,
          userData: {
            details: {
              first_name: accountDetails?.firstName,
              last_name: accountDetails?.secondName,
            },
            contacts: {
              email_primary: accountDetails?.email,
              phone_primary: accountDetails?.phone,
            },
            location: {
              address1: correspondenceAddress?.address1,
              address2: correspondenceAddress?.address2,
              address3: correspondenceAddress?.address3,
              address4: correspondenceAddress?.address4,
              flat: correspondenceAddress?.flat,
              building: correspondenceAddress?.building,
              street: correspondenceAddress?.street,
              city: correspondenceAddress?.city,
              country: correspondenceAddress?.country,
              postcode: correspondenceAddress?.postcode,
            },
            correspondence: {
              address1: correspondenceAddress?.address1,
              address2: correspondenceAddress?.address2,
              address3: correspondenceAddress?.address3,
              address4: correspondenceAddress?.address4,
              flat: correspondenceAddress?.flat,
              building: correspondenceAddress?.building,
              street: correspondenceAddress?.street,
              city: correspondenceAddress?.city,
              country: correspondenceAddress?.country,
              postcode: correspondenceAddress?.postcode,
            },
          },
          properties: prepareProperties(properties),
          payment_link_id: paymentLinkId || "",
          bank_transfer: bankTransfer || false,
        },
      });

      if (resp.errors?.length) {
        // throw Error(resp.errors[0]?.message);
      }
      // console.log({ props: prepareProperties(properties) });
      return resp.data?.admin?.createRemoteSalePayment?.stripe_token || "";
    },
    [client, userId, properties, prepareProperties]
  );

  const isFormValid = useCallback((): boolean => {
    if (paymentDetails.price === 0) {
      setError("No products are selected.");
      setTransactionInProgress(false);
      return false;
    }

    if (!correspondenceAddress) {
      setError("Corresponding address is required");
      return false;
    }

    return true;
  }, [paymentDetails, correspondenceAddress]);

  const onPaymentSucceeded = useCallback(() => {
    setPaymentSucceeded(true);
    setTimeout(() => setPaymentSucceeded(false), 15000);

    setPaymentDetails(EMPTY_PAYMENT_DETAILS);
    propertiesListEvents.emit(PropertiesListEvent.REFRESH.toString());
  }, [propertiesListEvents]);

  const onPaymentSubmit = useCallback(
    async (bankTransfer: boolean): Promise<void> => {
      setTransactionInProgress(true);
      setError("");

      if (!isFormValid()) {
        return;
      }

      try {
        const paymentToken = await createRemoteSalePayment(
          accountDetails,
          correspondenceAddress,
          "",
          bankTransfer
        );

        if (bankTransfer) {
          onPaymentSucceeded();
        } else if (paymentToken) {
          setPaymentConfirmToken(paymentToken);
        }
      } catch (err) {
        setError(String(err));
      } finally {
        setTransactionInProgress(false);
      }
    },
    [
      createRemoteSalePayment,
      isFormValid,
      accountDetails,
      correspondenceAddress,
      onPaymentSucceeded,
    ]
  );

  const onPaymentLinkCreate = useCallback(async (): Promise<void> => {
    setTransactionInProgress(true);
    setError("");

    try {
      const link = await invoiceService.createPaymentLink(paymentDetails);
      setPaymentLink(link);
      await createRemoteSalePayment(
        accountDetails,
        correspondenceAddress,
        link.id,
        false
      );
    } catch (err) {
      setError(String(err));
    } finally {
      setTransactionInProgress(false);
    }
  }, [
    invoiceService,
    createRemoteSalePayment,
    accountDetails,
    correspondenceAddress,
    paymentDetails,
  ]);

  const fetchStripeReceiptStatus = useCallback(
    async (intentId: string): Promise<cardpayment_api_PaymentStatusEnum> => {
      const resp = await client.query<
        CheckCardpaymentReceipt,
        CheckCardpaymentReceiptVariables
      >({
        query: CHECK_CARD_PAYMENT_RECEIPT,
        fetchPolicy: "no-cache",
        variables: {
          id: intentId,
          userId,
        },
      });

      return (
        resp.data.admin?.checkCardpaymentReceipt?.receipt.status ||
        cardpayment_api_PaymentStatusEnum.UNKNOWN_PAYMENT_STATUS
      );
    },
    [client, userId]
  );

  const onPaymentConfirmed = useCallback(
    async (intentId: string): Promise<void> => {
      let receiptStatus;
      try {
        receiptStatus = await fetchStripeReceiptStatus(intentId);
      } catch (err) {
        setError(String(err));
        setTransactionInProgress(false);
      }

      switch (receiptStatus) {
        case cardpayment_api_PaymentStatusEnum.PROCESSING:
        case cardpayment_api_PaymentStatusEnum.UNPAID:
          setTimeout(() => onPaymentConfirmed(intentId), 3000);
          return;
        case cardpayment_api_PaymentStatusEnum.SUCCEEDED:
          setTransactionInProgress(false);
          setPaymentConfirmToken("");
          onPaymentSucceeded();
          return;
        default:
          setError("Error while performing the transaction");
          setTransactionInProgress(false);
      }
    },
    [fetchStripeReceiptStatus, onPaymentSucceeded]
  );

  const onAccountBankDetailsUpdate = React.useCallback(
    async (bankDetails: BankDetails): Promise<void> => {
      setError("");
      setLoading(true);

      try {
        await accountService.updateAccount({
          id: userId,
          bankDetails,
        } as AccountDetails);
        setAccountDetails(await accountService.getAccountById(userId));
      } catch (err) {
        setError(String(err));
      } finally {
        setLoading(false);
      }
    },
    [accountService, userId]
  );

  return (
    <MainContainer>
      {loading && (
        <SpinnerContainer>
          <Spinner color={colors.mashPaleRed} size="md" />
        </SpinnerContainer>
      )}

      {!loading && (
        <AccountForm
          initialValues={accountDetails || ({} as AccountDetails)}
          onBankDetailsSubmit={onAccountBankDetailsUpdate}
        ></AccountForm>
      )}

      <PropertiesList
        userId={userId}
        onPropertiesChange={onPropertiesChange}
        events={propertiesListEvents}
      />

      {paymentDetails.price > 0 && (
        <Compliance
          amount={paymentDetails.price + paymentDetails.tax || 0}
          checked={complianceChecked}
          onChange={() => setComplianceChecked(!complianceChecked)}
        />
      )}

      {paymentDetails.price > 0 && complianceChecked && (
        <CorrespondenceAddress
          address={correspondenceAddress}
          onChange={setCorrespondenceAddress}
        ></CorrespondenceAddress>
      )}

      {error && <ErrorContainer>{error}</ErrorContainer>}
      {paymentSucceeded && (
        <SuccessfulPayment>Payment has been recieved.</SuccessfulPayment>
      )}

      {paymentDetails.price > 0 && complianceChecked && correspondenceAddress && (
        <StripeLoaderContextProvider>
          <PaymentForm
            paymentConfirmToken={paymentToken}
            payDetails={paymentDetails}
            onPaymentSubmit={onPaymentSubmit}
            paymentLink={paymentLink?.url || ""}
            onPaymentLinkCreate={onPaymentLinkCreate}
            onPaymentConfirmed={onPaymentConfirmed}
            transactionInProgress={transactionInProgress}
          />
        </StripeLoaderContextProvider>
      )}
    </MainContainer>
  );
};

export default withApollo(MainPage);
