import ApolloClient from "apollo-client";

import {
  AddressAutocomplete,
  AddressAutocompleteVariables,
} from "../graphql/queries/__generated__/AddressAutocomplete";
import {
  AddressGetByUrl,
  AddressGetByUrlVariables,
} from "../graphql/queries/__generated__/AddressGetByUrl";
import ADDRESS_AUTOCOMPLETE from "../graphql/queries/AddressAutocomplete.graphql";
import ADDRESS_GET_BY_URL from "../graphql/queries/AddressGetByUrl.graphql";
import { Address, AddressOption, createAddress } from "../models/address";

export interface AddressService {
  getSugestions: (filterLine: string) => Promise<Array<AddressOption>>;
  getAddressByUrl: (url: string) => Promise<Address>;
}

export const createAddressService = (
  client: ApolloClient<any>
): AddressService => {
  return {
    getSugestions: async (
      filterLine: string
    ): Promise<Array<AddressOption>> => {
      if (!filterLine) {
        return Promise.reject("No filter line is passed.");
      }

      const resp = await client.query<
        AddressAutocomplete,
        AddressAutocompleteVariables
      >({
        query: ADDRESS_AUTOCOMPLETE,
        fetchPolicy: "cache-first",
        variables: { query: filterLine },
      });

      if (resp.errors?.length) {
        return Promise.reject(resp.errors);
      }

      return (
        resp.data?.address?.autocomplete?.suggestions?.map((sg) => ({
          address: sg.suggestion,
          url: sg.udprn_url,
        })) || []
      );
    },

    getAddressByUrl: async (url: string): Promise<Address> => {
      if (!url) {
        return Promise.reject("No url param is passed.");
      }

      const resp = await client.query<
        AddressGetByUrl,
        AddressGetByUrlVariables
      >({
        query: ADDRESS_GET_BY_URL,
        fetchPolicy: "cache-first",
        variables: { url },
      });

      if (resp.errors?.length) {
        return Promise.reject(resp.errors);
      }

      const addr = resp.data?.address?.udprnurl?.address;
      return createAddress(addr);
    },
  };
};
