import ApolloClient from "apollo-client";

import {
  UpdatePropertyBankDetails,
  UpdatePropertyBankDetailsVariables,
} from "../graphql/mutations/__generated__/UpdatePropertyBankDetails";
import UPDATE_PROPERTY_BANK_DETAILS from "../graphql/mutations/UpdatePropertyBankDetails.graphql";
import { Property } from "../models/property";

export interface PropertyService {
  updateProperty: (property: Property) => Promise<void>;
}

export const createPropertyService = (
  client: ApolloClient<any>
): PropertyService => {
  return {
    updateProperty: async (property: Property): Promise<void> => {
      const resp = await client.query<
        UpdatePropertyBankDetails,
        UpdatePropertyBankDetailsVariables
      >({
        query: UPDATE_PROPERTY_BANK_DETAILS,
        fetchPolicy: "no-cache",
        variables: {
          propertyId: property.id,
          bankDetails: {
            account_name: property.bankDetails?.accountName,
            personal_reference: property.bankDetails?.personalReference,
            account_number: property.bankDetails?.accountNumber,
            sort_code: property.bankDetails?.sortCode,
          },
        },
      });

      if (resp.errors?.length) {
        throw new Error(resp.errors[0].message);
      }

      return;
    },
  };
};
