import React from "react";

import { ApolloConsumer, graphql, withApollo } from "react-apollo";
import { oc } from "ts-optchain";

import SUBSCRIBE_MESSAGING from "./graphql/subscribtion/Subscribe.graphql";

interface ContextProps {
  presence: any[];
}

export const SubscriptionContext = React.createContext<Partial<ContextProps>>({
  presence: [],
});

interface Props {
  client: any;
}

interface State {
  presence: any[];
}

class SubscribeProvider extends React.Component<Props, State> {
  static getDerivedStateFromProps(props, state) {
    /**TODO: use only for local component, check return null if nothing changed */
    let newState = { ...state };
    const event = oc(props).subscription.messaging.connect.event({});

    // статус пользователя онлайн или нет
    if (event && event.presence) {
      if (
        // если юзер подключился или вышел
        event.presence.users.length === 1 &&
        newState.presence.length &&
        newState.presence.find(
          (prsnc) => prsnc.user === event.presence.users[0].user
        )
      ) {
        newState = {
          ...newState,
          presence: newState.presence.map((prsnc) => {
            let p = { ...prsnc };

            if (p.user === event.presence.users[0].user) {
              p = event.presence.users[0];
            }
            return p;
          }),
        };
      } else if (
        newState.presence.length &&
        !newState.presence.find(
          (prsnc) => prsnc.user === event.presence.users[0].user
        )
      ) {
        //если юзера в списке еще не было
        newState = {
          ...newState,
          presence: [...newState.presence, ...event.presence.users],
        };
      } else {
        // первый запрос на список юзеров онлайн
        newState = {
          ...newState,
          presence: event.presence.users,
        };
      }
    }

    return newState;
  }

  constructor(props) {
    super(props);

    this.state = {
      presence: [],
    };
  }

  render() {
    const { children } = this.props;

    return (
      <SubscriptionContext.Provider value={this.state}>
        {children}
      </SubscriptionContext.Provider>
    );
  }
}

const SubscriptionProvider = (props) => (
  <ApolloConsumer>
    {(client) => <SubscribeProvider client={client} {...props} />}
  </ApolloConsumer>
);

export default withApollo<Props>(
  graphql<Props>(SUBSCRIBE_MESSAGING, { name: "subscription" })(
    SubscriptionProvider
  )
);
