import React, { FC, useCallback, useEffect, useMemo, useState } from "react";

import { useQuery } from "react-apollo";
import { Field } from "react-final-form";
import { OnChange } from "react-final-form-listeners";

import { common_api_generic_query_QueryFilterOperatorEnum as OperatorEnum } from "../../../globalTypes";
import { Select2 } from "../../../ui/atoms/Select2";
import { required } from "../../../util/validations";
import {
  PropertiesList,
  PropertiesListVariables,
} from "../../listing/graphql/queries/__generated__/PropertiesList";
import FETCH_PROPERTIES from "../../listing/graphql/queries/GetListOfProperties.graphql";
import { FindAddressProps } from "./types";

const itemToString = (i: { location: string; propertyId: string }) =>
  i.location;

const FindAddress: FC<FindAddressProps> = ({ setPropertyInput }) => {
  const [filterValue, setFilterValue] = useState<string>("");
  const [total, setTotal] = useState<number>(0);

  const { data, refetch } = useQuery<PropertiesList, PropertiesListVariables>(
    FETCH_PROPERTIES,
    {
      variables: {
        pagination: { page: 1, perPage: total },
        filter: [
          {
            fields: [
              "location.address1",
              "location.address2",
              "location.address3",
              "location.city",
              "location.postcode",
              "id",
              "ivr",
            ],
            operator: OperatorEnum.CONTAINS_ANY,
            value: [filterValue],
          },
        ],
      },
      skip: filterValue.length < 1,
    }
  );
  useEffect(() => {
    if (
      total === 0 &&
      data?.admin?.allProperties?.total !== undefined &&
      data?.admin?.allProperties?.total !== null
    ) {
      setTotal(data?.admin?.allProperties?.total);
      refetch();
    }
  }, [data, refetch, total]);

  const selectOptions = useMemo(
    () =>
      data?.admin?.allProperties?.data?.map((el) => ({
        location: [
          el.location.address1,
          el.location.address2,
          el.location.address3,
          el.location.city,
          el.location.postcode,
        ]
          .filter((el) => el)
          .join(", "),
        propertyId: el.id,
      })) ?? [],
    [data]
  );

  const handleInputValueChange = useCallback(
    (v: string | null) => setFilterValue(v ?? ""),
    []
  );
  return (
    <>
      <Field name="selectedLocation" validate={required()}>
        {({ input }) => (
          <Select2
            data-testid="find-address-by-postcode"
            input={input}
            itemToString={itemToString}
            label="Address"
            onInputValueChange={handleInputValueChange}
            options={selectOptions ?? []}
            readonly={false}
            withArrow={false}
          />
        )}
      </Field>

      <OnChange name="selectedLocation">
        {(value: any) => {
          if (value) {
            setPropertyInput((state) => {
              return {
                ...state,
                location: value.location,
                property_id: value.propertyId,
              };
            });
          }
        }}
      </OnChange>
    </>
  );
};

export default FindAddress;
