import React, { FC, useCallback, useState } from "react";

import AntdButton from "antd-button-color";

import { invoice_api_TransactionTypeEnum } from "../../globalTypes";
import { Td, Tr } from "../../ui/atoms/Table";
import { formatDate } from "../../util/date";
import { MatchTransactionForm } from "../payments/AccountStatement/Transaction/MatchTransactionForm";
import { GetTransactions_admin_allTransactions_transactions_matches } from "./graphql/__generated__/GetTransactions";
import { useTransactionMatchPropertyAddress } from "./hooks";

type ListItemProps = {
  amount: number;
  description: string;
  transaction_id: string;
  ivr: string;
  transactionMatches:
    | readonly GetTransactions_admin_allTransactions_transactions_matches[]
    | null;
  transaction_date: string;
  type: string;
};

const ListItem: FC<ListItemProps> = ({
  amount,
  description,
  transaction_id,
  ivr,
  transactionMatches,
  transaction_date,
  type,
}) => {
  const [buttonMerge, setButtonMerge] = useState<boolean>(false);

  const {
    address: transactionMatchPropertyAddress,
    cityPostcodeAndCountry: transactionMatchPropertyCityPostcodeAndCountry,
  } = useTransactionMatchPropertyAddress(transactionMatches);

  const withPrefilledPropertyAddress =
    Boolean(transactionMatchPropertyAddress) ||
    Boolean(transactionMatchPropertyCityPostcodeAndCountry);

  const handleMergeButtonClick = useCallback(
    () => setButtonMerge((state) => !state),
    []
  );

  return (
    <>
      <Tr>
        <Td colSpan={3}>
          <span>
            {withPrefilledPropertyAddress ? (
              <>
                {transactionMatchPropertyAddress}
                {transactionMatchPropertyCityPostcodeAndCountry && (
                  <div>{transactionMatchPropertyCityPostcodeAndCountry}</div>
                )}
              </>
            ) : (
              description
            )}
          </span>
        </Td>
        <Td colSpan={2}>
          <span>£{amount}</span>
        </Td>
        <Td colSpan={2}>
          <span>{ivr}</span>
        </Td>
        <Td colSpan={2}>
          <span>{formatDate(transaction_date)}</span>
        </Td>
        <Td colSpan={1}>
          <span>
            {type === invoice_api_TransactionTypeEnum.TRANSACTION_TYPE_DEBIT
              ? "Debit"
              : "Credit"}
          </span>
        </Td>
        <Td colSpan={2}>
          {!withPrefilledPropertyAddress && (
            <AntdButton block onClick={handleMergeButtonClick} type="link">
              Merge
            </AntdButton>
          )}
        </Td>
      </Tr>
      {!withPrefilledPropertyAddress && buttonMerge && (
        <Tr>
          <Td colSpan={12}>
            <MatchTransactionForm
              buttonText="Complete merge"
              onSubmit={() => setButtonMerge(false)}
              transactionId={transaction_id}
              transactionMatches={transactionMatches}
            />
          </Td>
        </Tr>
      )}
    </>
  );
};

export default ListItem;
