import { useMemo } from "react";

import { invoice_api_TransactionMatchEnum } from "../../../globalTypes";
import { PaymentsGetTransaction_admin_Transaction_matches } from "../../payments/graphql/queries/__generated__/PaymentsGetTransaction";
import { GetTransactions_admin_allTransactions_transactions_matches } from "../graphql/__generated__/GetTransactions";

const joinByComma = (items: Array<string | null>) =>
  items.filter(Boolean).join(", ");

export const useTransactionMatchPropertyAddress = (
  transactionMatches:
    | readonly (
        | GetTransactions_admin_allTransactions_transactions_matches
        | PaymentsGetTransaction_admin_Transaction_matches
      )[]
    | null
) => {
  const transactionMatch = useMemo(
    () =>
      transactionMatches?.find((match) =>
        match.matched?.includes(
          invoice_api_TransactionMatchEnum.TRANSACTION_MATCH_IVR
        )
      ),
    [transactionMatches]
  );

  const location = transactionMatch?.payment?.property?.location;

  return useMemo(() => {
    if (!location) {
      return { address: "", cityPostcodeAndCountry: "" };
    }

    return {
      address: joinByComma([
        location.address1,
        location.address2,
        location.address3,
        location.address4,
      ]),
      cityPostcodeAndCountry: joinByComma([
        location.city,
        location.postcode,
        location.country,
      ]),
    };
  }, [location]);
};
