import styled from "@emotion/styled";

import theme from "../theme";

import css from "@emotion/css";

export const UserForm = styled.div`
  max-width: 460px;
  margin: 0 auto;
  padding-bottom: 60px;
`;

export const UserFormWrapper = styled.div`
  background: ${theme.colors.main.lightGrey};
  padding: 40px 50px;
  border: solid 1px ${theme.colors.main.midGrey};
  border-radius: 5px;
  position: relative;
  margin-bottom: 20px;
`;

export const UserFormOverlay = styled.div`
  background: ${theme.colors.main.lightGrey};
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  opacity: 0.5;
  z-index: 9;
`;

export const UserFormGroup = styled.div`
  margin: 0 0 45px;
`;

export const UserFormAction = styled.div`
  display: flex;
  flex-direction: column;
  width: 100%;

  > button,
  > a.link-button {
    width: 100%;
    margin-bottom: 20px;

    > button {
      width: 100%;
    }

    &:last-child {
      margin-bottom: 0;
    }
  }
`;

export const ButtonsGroup = styled.div`
  padding-bottom: 10px;
  display: flex;
  justify-content: space-between;
  flex-direction: row;

  button {
    flex: 1;
    margin-right: 32px;

    &:last-child {
      margin-right: 0;
    }

    &:only-child {
      width: 100%;
    }
  }
`;

type UserFormRowProps = {
  disabled?: boolean;
};
export const UserFormRow = styled("div")<UserFormRowProps>`
  margin: 0 0 25px;

  &:last-of-type {
    margin-bottom: 0;
  }

  label {
    font-size: 16px;
    display: block;
    margin: 0 0 8px;
    user-select: none;
    cursor: pointer;
    position: relative;
    font-weight: 500;
  }

  ${({ disabled }) =>
    disabled &&
    css`
      label {
        cursor: default;
        opacity: 0.65;
      }
    `}
`;

export const UserFormRowFlex = styled.div`
  margin: 0 -15px 25px;
  display: flex;

  &:last-of-type {
    margin-bottom: 0;
  }
`;

export const UserFormItem = styled(UserFormRow)`
  width: calc(33.333% - 30px);
  margin: 0 15px;
`;

export const UserFormValue = styled.div`
  font-weight: 500;
  font-size: 16px;
`;

export const UserFormActionRight = styled.div`
  margin-right: auto;
  align-self: center;
`;
