import { useCallback, useLayoutEffect } from "react";

const useModal = (onCancel: () => void, onConfirm?: () => void) => {
  const onEscape = useCallback(
    (event: KeyboardEvent) => {
      if (event.code === "Escape") {
        onCancel();
      } else if (onConfirm != null && event.code === "Enter") {
        onConfirm();
      }
    },
    [onCancel, onConfirm]
  );

  useLayoutEffect(() => {
    document.addEventListener("keydown", onEscape, false);

    return () => {
      document.removeEventListener("keydown", onEscape);
    };
  }, [onEscape]);
};

export default useModal;
