import React from "react";

import styled from "@emotion/styled";

import theme from "../theme";

export const CheckboxToggle = ({ labelText, input, ...rest }: any) => {
  return (
    <Label>
      <LabelText>{labelText}</LabelText>
      <input type="checkbox" {...input} {...rest} />
      <Switcher>
        <SwitcherOn className="on" data-testid="switcher_on">
          ON
        </SwitcherOn>
        <SwitcherCircle className="circle" />
        <SwitcherOff className="off" data-testid="switcher_off">
          OFF
        </SwitcherOff>
      </Switcher>
    </Label>
  );
};
export const CheckboxToggleDisabled = ({ labelText, input, ...rest }: any) => {
  return (
    <Label>
      <LabelText>{labelText}</LabelText>
      <input type="checkbox" {...input} {...rest} />
      <SwitcherDisabled />
    </Label>
  );
};
const Switcher = styled.span`
  position: absolute;
  height: 26px;
  width: 66px;
  overflow: hidden;
  background: ${theme.colors.main.lightGrey};
  border: solid 1px ${theme.colors.main.midGrey};
  border-radius: 13px;
  transition: all 0.25s;
  color: #9d9da6;
  line-height: 24px;
  font-size: 14px;
  font-weight: 700;
  text-align: center;
  top: 0;
  right: 0;
`;
const SwitcherDisabled = styled(Switcher)`
  background: ${theme.colors.icons.darkBlue};
  border: solid 3px white;
  width: 26px;
`;
const SwitcherOn = styled.span`
  position: absolute;
  width: 46px;
  top: 0;
  left: -46px;
  transition: all 0.25s;
`;
const SwitcherOff = styled.span`
  position: absolute;
  width: 46px;
  top: 0;
  left: 18px;
  transition: all 0.25s;
`;
const SwitcherCircle = styled.span`
  position: absolute;
  width: 14px;
  top: 5px;
  left: 7px;
  height: 14px;
  background: #9d9da6;
  border-radius: 50%;
  transition: all 0.25s;
`;
const LabelText = styled.strong``;
const Label = styled.label`
  cursor: pointer;
  display: block;
  position: relative;
  margin: 0 0 20px;
  padding: 0 80px 0 0;
  font-size: 16px;
  font-weight: 500;
  line-height: 26px;
  width: 100%;
  overflow: hidden;
  &:last-of-type {
    margin-bottom: 0;
  }
  input {
    position: absolute;
    left: -9999px;
    &:checked {
      ~ span {
        background: ${theme.colors.main.green};
        border-color: ${theme.colors.main.green};
        color: white;
        .on {
          left: 0;
        }
        .off {
          left: 66px;
        }
        .circle {
          left: 43px;
          background: white;
        }
      }
    }
  }
`;

// export const CheckboxToggle = ({
//   labelText,
//   input,
//   onChange,
//   ...rest
// }: any) => {
//   return (
//     <Label>
//       <LabelText>{labelText}</LabelText>
//       <input
//         {...input}
//         {...rest}
//         onChange={e => {
//           onChange(e);
//           input.onChange(e);
//         }}
//         type="checkbox"
//       />
//       <Switcher>
//         <SwitcherOn className="on">ON</SwitcherOn>
//         <SwitcherCircle className="circle" />
//         <SwitcherOff className="off">OFF</SwitcherOff>
//       </Switcher>
//     </Label>
//   );
// };

// export const CheckboxToggleDisabled = ({ labelText, input, ...rest }: any) => {
//   return (
//     <Label>
//       <LabelText>{labelText}</LabelText>
//       <input type="checkbox" {...input} {...rest} />
//       <SwitcherDisabled />
//     </Label>
//   );
// };

// const Switcher = styled.span`
//   position: absolute;
//   height: 26px;
//   width: 66px;
//   overflow: hidden;
//   background: ${theme.colors.main.lightGrey};
//   border: solid 1px ${theme.colors.main.midGrey};
//   border-radius: 13px;
//   transition: all 0.25s;
//   color: #9d9da6;
//   line-height: 24px;
//   font-size: 14px;
//   font-weight: 700;
//   text-align: center;
//   top: 0;
//   right: 0;
// `;
// const SwitcherDisabled = styled(Switcher)`
//   background: ${theme.colors.icons.darkBlue};
//   border: solid 3px white;
//   width: 26px;
// `;

// const SwitcherOn = styled.span`
//   position: absolute;
//   width: 46px;
//   top: 0;
//   left: -46px;
//   transition: all 0.25s;
// `;
// const SwitcherOff = styled.span`
//   position: absolute;
//   width: 46px;
//   top: 0;
//   left: 18px;
//   transition: all 0.25s;
// `;
// const SwitcherCircle = styled.span`
//   position: absolute;
//   width: 14px;
//   top: 5px;
//   left: 7px;
//   height: 14px;
//   background: #9d9da6;
//   border-radius: 50%;
//   transition: all 0.25s;
// `;
// const LabelText = styled.strong``;
// const Label = styled.label`
//   cursor: pointer;
//   display: block;
//   position: relative;
//   margin: 0 0 20px;
//   padding: 0 80px 0 0;
//   font-size: 16px;
//   font-weight: 500;
//   line-height: 26px;
//   width: 100%;
//   overflow: hidden;

//   &:last-of-type {
//     margin-bottom: 0;
//   }

//   input {
//     position: absolute;
//     left: -9999px;

//     &:checked {
//       ~ span {
//         background: ${theme.colors.main.green};
//         border-color: ${theme.colors.main.green};
//         color: white;

//         .on {
//           left: 0;
//         }

//         .off {
//           left: 66px;
//         }

//         .circle {
//           left: 43px;
//           background: white;
//         }
//       }
//     }
//   }
// `;
