import React from "react";

import styled from "@emotion/styled";

import theme from "../theme";

type Props = {
  total: number;
  curPage: number;
  changePage(arg0: number): void;
  showNPages?: number;
};

const Pagebar = ({
  total = 1,
  curPage = 0,
  showNPages = 5,
  changePage,
}: Props) => {
  if (total < 2) {
    return <Pager />;
  }

  const middlePagesNumbers: number[] = [];
  const middleStart = Math.max(2, curPage - 2);
  const middleEnd = Math.min(curPage + showNPages, total - 1);

  for (let i = middleStart; i <= middleEnd; i++) {
    middlePagesNumbers.push(i);
  }

  return (
    <Pager>
      {total > 1 && curPage > 1 && (
        <Page
          className="pagebar__arrow"
          onClick={() => changePage(curPage - 1)}
        >
          <span className="material-icons">chevron_left</span>
        </Page>
      )}
      <Page
        className={1 === curPage ? "pager-selected" : "pager-item"}
        onClick={() => changePage(1)}
      >
        1
      </Page>
      {middleStart > 2 && <Hellipsis>...</Hellipsis>}
      {middlePagesNumbers.length > 0 && (
        <>
          {middlePagesNumbers.map((pageIndex) => (
            <Page
              key={pageIndex}
              className={
                pageIndex === curPage ? "pager-selected" : "pager-item"
              }
              onClick={() => changePage(pageIndex)}
            >
              {pageIndex}
            </Page>
          ))}
        </>
      )}
      {middleEnd < total - 1 && <Hellipsis>...</Hellipsis>}
      {total > 1 && (
        <Page
          className={total === curPage ? "pager-selected" : "pager-item"}
          onClick={() => changePage(total)}
        >
          {total}
        </Page>
      )}
      {total > 1 && curPage < total && (
        <Page
          className="pagebar__arrow"
          onClick={() => changePage(curPage + 1)}
        >
          <span className="material-icons">chevron_right</span>
        </Page>
      )}
    </Pager>
  );
};

const Pager = styled.ul`
  display: flex;
  align-items: center;
  justify-content: center;
  list-style: none;
  padding: 0 0 10px;
  margin: 0;
`;
const Page = styled.li`
  padding: 0 12px;
  cursor: pointer;
  border: 0;
  background: transparent;
  margin: 0 5px;
  color: ${theme.colors.main.mainBlue};
  font-weight: 700;
  font-size: 16px;
  border: solid 1px #d8d8d8;
  min-width: 40px;
  height: 40px;
  display: inline-flex;
  align-items: center;
  justify-content: center;

  &.pager-selected {
    color: #fff;
    background: ${theme.colors.main.mainBlue};
    border-color: ${theme.colors.main.mainBlue};
  }

  &.pagebar__arrow span {
    transform: scale(1.3);
    display: block;
  }
`;
const Hellipsis = styled.li`
  font-weight: 700;
  letter-spacing: 3px;
  margin: 0 12px;
  padding-left: 3px;
`;

export default Pagebar;
