import { useState } from "react";

export type SortableProps = {
  field?: string[] | [];
  order?: number;
};

const Sortable = (
  props: SortableProps & {
    children: (v: {
      field: string[];
      setField: (v: string[]) => void;
      order: number;
      setOrder: (v: number) => void;
      setSort: (v: SortableProps) => void;
    }) => JSX.Element;
  }
) => {
  const [field, setField] = useState(props.field || []);
  const [order, setOrder] = useState(props.order || 1);

  const setSort = ({ field, order }: SortableProps): void => {
    setField(field || []);
    setOrder(order || 1);
  };

  return props.children({
    field,
    setField,
    order,
    setOrder,
    setSort,
  });
};

export const useSortable = (props: SortableProps) => {
  const [field, setField] = useState(props.field || []);
  const [order, setOrder] = useState(props.order || 1);

  const setSort = ({ field, order }: SortableProps): void => {
    setField(field || []);
    setOrder(order || 1);
  };
  return { field, setField, order, setOrder, setSort };
};

export default Sortable;
