import { memo, useState } from "react";

import styled from "@emotion/styled";

import theme from "../theme";

type Props = {
  children: any;
  defaultTab?: number;
};

const Tabs = memo((props: Props) => {
  const [curTabIndex, setTab] = useState(props.defaultTab || 0);

  return props.children({
    curTabIndex,
    setTab,
    TabList,
    TabItem,
    TabActive,
    TabBody,
    TabDisabled,
  });
});

const TabList = styled.ul`
  list-style: none;
  padding: 0;
  margin: 0 -20px;
  display: flex;
`;
const TabItem = styled.li`
  padding: 10px 20px;
  font-size: 16px;
  font-weight: 500;
  cursor: pointer;
  border-bottom: solid 3px transparent;
  text-align: center;
`;
const TabActive = styled(TabItem)`
  cursor: default;
  border-bottom: solid 3px ${theme.colors.icons.darkBlue};
  color: ${theme.colors.icons.darkBlue};
`;
const TabDisabled = styled(TabItem)`
  cursor: default;
  opacity: 0.25;
`;
const TabBody = styled.div`
  padding: 30px 40px;
  margin: 0 -40px;
  background: ${theme.colors.main.lightGrey};
  border-top: solid 1px ${theme.colors.main.midGrey};
  border-bottom: solid 1px ${theme.colors.main.midGrey};
  min-height: calc(100vh - 460px);
`;

export default Tabs;
