import { AxiosResponse } from "axios";

/* eslint-disable import/prefer-default-export */
const FILENAME_REGEXP = /filename\*=[^']+''(.*);?$/;

export const downloadFileUsingBlob = (
  response: AxiosResponse<BlobPart>,
  defaultFileName: string
) => {
  const downloadUrl = window.URL.createObjectURL(
    new Blob([response.data], { type: "application/pdf" })
  );
  const link = document.createElement("a");
  link.href = downloadUrl;

  const contentDispositionHeader: string | undefined =
    response.headers["content-disposition"];

  const res = FILENAME_REGEXP.exec(contentDispositionHeader ?? "");
  const filename = res != null ? decodeURIComponent(res[1]) : defaultFileName;

  link.setAttribute("download", filename);

  document.body.appendChild(link);
  link.click();
  link.remove();
  setTimeout(() => window.URL.revokeObjectURL(downloadUrl), 100);
};
