import get from "lodash.get";

import {
  common_api_generic_query_QueryFilterOperatorEnum as FilterOperatorEnum,
  common_api_generic_query_QueryParamsFilterInput as ParamsFilterInput,
} from "../globalTypes";

export type FilterProps = {
  operator: FilterOperatorEnum;
  field: string;
  value: string | string[];
};

export const makeFilters = ({ values, filters }): ParamsFilterInput[] =>
  filters
    .filter(({ key, operator }) => {
      if (operator === FilterOperatorEnum.RANGE) {
        return get(values, "min") && get(values, "max");
      }

      return !!get(values, key);
    })
    .map(({ key, operator, fields, transformation, not }) => {
      if (operator === FilterOperatorEnum.RANGE) {
        return {
          operator: FilterOperatorEnum[operator],
          fields,
          value: [get(values, "min"), get(values, "max")],
          transformation,
        };
      }

      return {
        operator: FilterOperatorEnum[operator],
        fields,
        value: get(values, key).toString(),
        transformation,
        not,
      };
    });
